(define-module (glicid packages cups)
  #:use-module (gnu packages)
  #:use-module (gnu packages algebra)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages avahi)
  #:use-module (gnu packages base)
  #:use-module (gnu packages bash)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages crypto)
  #:use-module (gnu packages fonts)     ; font-dejavu
  #:use-module (gnu packages fontutils)
  #:use-module (gnu packages ghostscript)
  #:use-module (gnu packages glib)
  #:use-module (gnu packages groff)
  #:use-module (gnu packages image)
  #:use-module (gnu packages libusb)
  #:use-module (gnu packages linux)
  #:use-module (gnu packages pdf)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages photo)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages polkit)
  #:use-module (gnu packages pretty-print)
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages qt)
  #:use-module (gnu packages scanner)
  #:use-module (gnu packages tls)
  #:use-module (guix build-system cmake)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system meson)
  #:use-module (guix build-system python)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix gexp)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix packages)
  #:use-module (guix utils)
  #:use-module (srfi srfi-1)
  #:use-module (ice-9 match)
  #:use-module (gnu packages cups)


  #:use-module (gnu packages)
  #:use-module (gnu packages algebra)
   #:use-module (gnu packages python-xyz)
   #:use-module (gnu packages qt)
   #:use-module (gnu packages scanner)
   #:use-module (gnu packages time)
   #:use-module (gnu packages tls)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system python)
)
 
(define-public gutenprint
 (package
   (name "gutenprint")
   (version "5.3.4")
   (source
    (origin
      (method url-fetch)
      (uri (string-append "mirror://sourceforge/gimp-print/" name "-"
                          (version-major+minor version) "/" version "/"
                          name "-" version ".tar.xz"))
      (sha256
       (base32 "0fq2y9sx37d342fihp1ys9kf4sr2j5nc1kl33j9sirmqs80sfi6v"))))
   (build-system gnu-build-system)
   (arguments
    `(#:test-target "check-parallel"
      #:configure-flags (list "--enable-cups-level3-ppds"
                              "--enable-globalized-cups-ppds"
                              "--enable-cups-ppds"
                              "--enable-cups-1_2-enhancements")
      #:phases
      (modify-phases %standard-phases
        (add-before 'configure 'fix-paths
          (lambda* (#:key outputs native-inputs #:allow-other-keys)
            (substitute* "Makefile.in"
              (("/usr/bin/time") "time"))
            (let ((out (assoc-ref outputs "out")))
              (substitute* (find-files "." "^(Makefile|Makefile\\.in|configure)$")
                (("^(\\s*)cups_conf_serverbin(\\s*)=(.+)$")
                 (string-append "cups_conf_serverbin=" out "/lib/cups\n"))
                (("^(\\s*)cups_conf_serverroot(\\s*)=(.+)$")
                 (string-append "cups_conf_serverroot=" out "/etc/cups\n"))
                (("^(\\s*)cups_conf_datadir(\\s*)=(.+)$")
                 (string-append "cups_conf_datadir=" out "/share/cups\n")))
              (substitute* "src/cups/Makefile.in"
                (("^(\\s*)bindir(\\s*)=(.+)$")
                 (string-append "bindir = " out "/bin\n"))
                (("^(\\s*)sbindir(\\s*)=(.+)$")
                 (string-append "sbindir = " out "/sbin\n")))
              #t))))))
   (native-inputs
    `(("perl" ,perl)
      ("time" ,time)))
   (inputs
    `(("cups" ,cups-minimal)))
   (synopsis "Printer drivers for CUPS on GNU/Linux")
   ;; Supported printers list from:
   ;; http://gimp-print.sourceforge.net/p_Supported_Printers.php
   ;; Remember to update on version bumps with this command:
   ;; $ curl http://gimp-print.sourceforge.net/p_Supported_Printers.php | \
   ;; grep -Po '(?<=^<tr><td>).+?(?=</td>)' | sed 's/^/@item /g'
   (description "Printer drivers for
CUPS on GNU/Linux, Macintosh OS X, and other POSIX-compliant operating systems.
This project also maintains an enhanced Print plug-in for GIMP 2.x from
the same code base.  This driver claims to support these printers:

enumerate
item Canon BJ-30
item Canon BJC-50
item Canon BJC-55
item Canon BJC-80
item Canon BJC-85
item Canon BJC-210
item Canon BJC-240
item Canon BJC-250
item Canon BJC-1000
item Canon BJC-2000
item Canon BJC-2010
item Canon BJC-2100
item Canon BJC-2110
item Canon BJC-3000
item Canon BJC-4000
item Canon BJC-4300
item Canon BJC-4400
item Canon BJC-4550
item Canon BJC-5100
item Canon BJC-5500
item Canon BJC-5500J
item Canon BJC-6000
item Canon BJC-6100
item Canon BJC-6200
item Canon BJC-6500
item Canon BJC-7000
item Canon BJC-7100
item Canon BJC-8200
item Canon BJC-8500
item Canon S100
item Canon S200
item Canon S300
item Canon S330
item Canon S400
item Canon S450
item Canon S500
item Canon S520
item Canon S530D
item Canon S600
item Canon S630
item Canon S750
item Canon S800
item Canon S820
item Canon S830D
item Canon S900
item Canon S9000
item Canon S4500
item Canon SELPHY DS700
item Canon SELPHY DS810
item Canon PIXMA mini220
item Canon PIXUS mini220
item Canon PIXMA mini320
item Canon PIXMA mini360
item Canon PIXUS mini360
item Canon iP90 series
item Canon PIXMA iP90
item Canon PIXUS iP90
item Canon PIXMA iP90v
item Canon PIXUS iP90v
item Canon iP110 series
item Canon PIXMA iP110
item Canon PIXUS iP110
item Canon iP2000 series
item Canon PIXMA iP2000
item Canon PIXUS iP2000
item Canon iP2700 series
item Canon PIXMA iP2700
item Canon PIXUS iP2700
item Canon PIXMA iP2701
item Canon PIXMA iP2702
item Canon PIXMA iP2740
item Canon PIXMA iP2760
item Canon PIXMA iP2770
item Canon PIXMA iP2772
item Canon PIXMA iP2780
item Canon PIXMA iP2788
item Canon iP2800 series
item Canon PIXMA iP2810
item Canon PIXMA iP2820
item Canon PIXMA iP2840
item Canon PIXMA iP2850
item Canon PIXMA iP2870
item Canon PIXMA iP2872
item Canon PIXMA iP2880
item Canon PIXMA iP2890
item Canon PIXMA iP2899
item Canon PIXMA iP3000
item Canon PIXMA iP3100
item Canon PIXUS iP3100
item Canon iP3300 series
item Canon PIXMA iP3300
item Canon PIXUS iP3300
item Canon iP3500 series
item Canon PIXMA iP3500
item Canon PIXUS iP3500
item Canon iP3600 series
item Canon PIXMA iP3600
item Canon PIXUS iP3600
item Canon PIXMA iP3680
item Canon PIXMA iP4000
item Canon PIXMA iP4000R
item Canon PIXMA iP4100
item Canon PIXUS iP4100
item Canon PIXUS iP4100R
item Canon PIXMA iP4100R
item Canon iP4200 series
item Canon PIXMA iP4200
item Canon PIXUS iP4200
item Canon iP4300 series
item Canon PIXMA iP4300
item Canon PIXUS iP4300
item Canon iP4500 series
item Canon PIXMA iP4500
item Canon PIXUS iP4500
item Canon iP4600 series
item Canon PIXMA iP4600
item Canon PIXUS iP4600
item Canon PIXMA iP4680
item Canon iP4700 series
item Canon PIXMA iP4700
item Canon PIXUS iP4700
item Canon PIXMA iP4760
item Canon iP4800 series
item Canon PIXMA iP4800
item Canon PIXMA iP4810
item Canon PIXMA iP4820
item Canon PIXUS iP4830
item Canon PIXMA iP4840
item Canon PIXMA iP4850
item Canon PIXMA iP4870
item Canon PIXMA iP4880
item Canon iP4900 series
item Canon PIXMA iP4900
item Canon PIXMA iP4910
item Canon PIXMA iP4920
item Canon PIXUS iP4930
item Canon PIXMA iP4940
item Canon PIXMA iP4950
item Canon PIXMA iP4970
item Canon PIXMA iP4980
item Canon PIXMA iP5000
item Canon PIXMA iP5200
item Canon iP5200R series
item Canon PIXMA iP5200R
item Canon PIXUS iP5200R
item Canon PIXMA iP5300
item Canon PIXMA iP6000D
item Canon PIXMA iP6100D
item Canon PIXUS iP6100D
item Canon PIXMA iP6210D
item Canon PIXMA iP6220D
item Canon PIXMA iP6310D
item Canon PIXMA iP6320D
item Canon iP6600D series
item Canon PIXMA iP6600D
item Canon PIXUS iP6600D
item Canon iP6700D series
item Canon PIXMA iP6700D
item Canon PIXUS iP6700D
item Canon PIXMA iP7100
item Canon PIXUS iP7100
item Canon iP7200 series
item Canon PIXMA iP7210
item Canon PIXMA iP7220
item Canon PIXUS iP7230
item Canon PIXMA iP7240
item Canon PIXMA iP7250
item Canon PIXMA iP7260
item Canon PIXMA iP7270
item Canon PIXMA iP7280
item Canon PIXMA iP7500
item Canon PIXUS iP7500
item Canon PIXMA iP8100
item Canon PIXUS iP8100
item Canon PIXMA iP8500
item Canon PIXMA iP8600
item Canon PIXUS iP8600
item Canon iP8700 series
item Canon PIXMA iP7810
item Canon PIXMA iP8720
item Canon PIXUS iP8730
item Canon PIXMA iP8740
item Canon PIXMA iP8750
item Canon PIXMA iP8760
item Canon PIXMA iP8770
item Canon PIXMA iP8780
item Canon PIXMA iP9910
item Canon PIXUS iP9910
item Canon PIXMA iX4000
item Canon iX5000 series
item Canon PIXMA iX5000
item Canon PIXUS iX5000
item Canon iX6500 series
item Canon PIXMA iX6500
item Canon PIXMA iX6510
item Canon PIXMA iX6520
item Canon PIXUS iX6530
item Canon PIXMA iX6540
item Canon PIXMA iX6550
item Canon PIXMA iX6560
item Canon PIXMA iX6580
item Canon iX6700 series
item Canon PIXMA iX6770
item Canon PIXMA iX6780
item Canon iX6800 series
item Canon PIXMA iX6810
item Canon PIXMA iX6820
item Canon PIXUS iX6830
item Canon PIXMA iX6840
item Canon PIXMA iX6850
item Canon PIXMA iX6860
item Canon PIXMA iX6870
item Canon PIXMA iX6880
item Canon iX7000 series
item Canon PIXMA iX7000
item Canon PIXUS iX7000
item Canon Pro9000 series
item Canon PIXMA Pro9000
item Canon PIXUS Pro9000
item Canon Pro9000 Mk.II series
item Canon PIXMA Pro9000mk2
item Canon PIXUS Pro9000mk2
item Canon Pro9500 series
item Canon PIXMA Pro9500
item Canon PIXUS Pro9500
item Canon Pro9500 Mk.II series
item Canon PIXMA Pro9500mk2
item Canon PIXUS Pro9500mk2
item Canon SmartBase MPC400
item Canon SmartBase MPC600F
item Canon PIXUS MP55
item Canon MP140 series
item Canon PIXMA MP140
item Canon PIXMA MP145
item Canon MP150 series
item Canon PIXMA MP150
item Canon MP160 series
item Canon PIXMA MP160
item Canon MP170 series
item Canon PIXMA MP170
item Canon PIXUS MP170
item Canon MP180 series
item Canon PIXMA MP180
item Canon MP190 series
item Canon PIXMA MP190
item Canon PIXMA MP198
item Canon MP210 series
item Canon PIXMA MP210
item Canon PIXMA MP218
item Canon MP220 series
item Canon PIXMA MP220
item Canon PIXMA MP228
item Canon MP230 series
item Canon PIXMA MP230
item Canon PIXMA MP236
item Canon PIXMA MP237
item Canon MP240 series
item Canon PIXMA MP240
item Canon PIXMA MP245
item Canon MP250 series
item Canon PIXMA MP250
item Canon PIXMA MP252
item Canon PIXMA MP258
item Canon PIXMA MP259
item Canon MP260 series
item Canon PIXMA MP260
item Canon PIXMA MP268
item Canon MP270 series
item Canon PIXMA MP270
item Canon PIXUS MP270
item Canon PIXMA MP272
item Canon PIXMA MP276
item Canon MP280 series
item Canon PIXMA MP280
item Canon PIXUS MP280
item Canon PIXMA MP282
item Canon PIXMA MP287
item Canon PIXMA MP288
item Canon MP360 series
item Canon PIXMA MP360
item Canon PIXUS MP360
item Canon SmartBase MP360
item Canon SmartBase MP360S
item Canon MultiPASS MP360
item Canon MP370 series
item Canon PIXMA MP370
item Canon PIXUS MP370
item Canon SmartBase MP370
item Canon MultiPASS MP370
item Canon PIXMA MP375R
item Canon PIXUS MP375R
item Canon MP390 series
item Canon PIXMA MP390
item Canon PIXUS MP390
item Canon SmartBase MP390
item Canon MultiPASS MP390
item Canon MP450 series
item Canon PIXMA MP450
item Canon PIXUS MP450
item Canon MP460 series
item Canon PIXMA MP460
item Canon PIXUS MP460
item Canon MP470 series
item Canon PIXMA MP470
item Canon PIXUS MP470
item Canon PIXMA MP476
item Canon MP480 series
item Canon PIXMA MP480
item Canon PIXUS MP480
item Canon PIXMA MP486
item Canon MP490 series
item Canon PIXMA MP490
item Canon PIXUS MP490
item Canon PIXMA MP492
item Canon PIXMA MP493
item Canon PIXUS MP493
item Canon PIXMA MP495
item Canon PIXMA MP496
item Canon PIXMA MP497
item Canon PIXMA MP498
item Canon PIXMA MP499
item Canon MP500 series
item Canon PIXMA MP500
item Canon PIXUS MP500
item Canon MP510 series
item Canon PIXMA MP510
item Canon PIXUS MP510
item Canon MP520 series
item Canon PIXMA MP520
item Canon PIXUS MP520
item Canon MP530 series
item Canon PIXMA MP530
item Canon MP540 series
item Canon PIXMA MP540
item Canon PIXUS MP540
item Canon PIXMA MP545
item Canon MP550 series
item Canon PIXMA MP550
item Canon PIXUS MP550
item Canon PIXMA MP558
item Canon MP560 series
item Canon PIXMA MP560
item Canon PIXUS MP560
item Canon PIXMA MP568
item Canon MP600 series
item Canon PIXMA MP600
item Canon PIXUS MP600
item Canon PIXMA MP600R
item Canon MP610 series
item Canon PIXMA MP610
item Canon PIXUS MP610
item Canon MP620 series
item Canon PIXMA MP620
item Canon PIXMA MP620B
item Canon PIXUS MP620
item Canon PIXMA MP628
item Canon MP630 series
item Canon PIXMA MP630
item Canon PIXUS MP630
item Canon PIXMA MP638
item Canon MP640 series
item Canon PIXMA MP640
item Canon PIXMA MP640R
item Canon PIXUS MP640
item Canon PIXMA MP648
item Canon MP700 series
item Canon PIXMA MP700
item Canon PIXUS MP700
item Canon SmartBase MP700
item Canon MultiPASS MP700
item Canon MP710 series
item Canon PIXMA MP710
item Canon PIXUS MP710
item Canon MP730 series
item Canon PIXMA MP730
item Canon PIXUS MP730
item Canon SmartBase MP730
item Canon MultiPASS MP730
item Canon MP740 series
item Canon PIXMA MP740
item Canon PIXUS MP740
item Canon MP750 series
item Canon PIXMA MP750
item Canon MP760 series
item Canon PIXMA MP760
item Canon MP770 series
item Canon PIXMA MP770
item Canon PIXUS MP770
item Canon MP780 series
item Canon PIXMA MP780
item Canon MP790 series
item Canon PIXMA MP790
item Canon PIXUS MP790
item Canon MP800 series
item Canon PIXMA MP800
item Canon PIXUS MP800
item Canon PIXMA MP800R
item Canon MP810 series
item Canon PIXMA MP810
item Canon PIXUS MP810
item Canon MP830 series
item Canon PIXMA MP830
item Canon PIXUS MP830
item Canon MP900 series
item Canon PIXMA MP900
item Canon PIXUS MP900
item Canon MP950 series
item Canon PIXMA MP950
item Canon PIXUS MP950
item Canon MP960 series
item Canon PIXMA MP960
item Canon PIXUS MP960
item Canon MP970 series
item Canon PIXMA MP970
item Canon PIXUS MP970
item Canon MP980 series
item Canon PIXMA MP980
item Canon PIXUS MP980
item Canon PIXMA MP988
item Canon MP990 series
item Canon PIXMA MP990
item Canon PIXUS MP990
item Canon PIXMA MP996
item Canon MG2100 series
item Canon PIXMA MG2100
item Canon PIXMA MG2110
item Canon PIXMA MG2120
item Canon PIXUS MG2130
item Canon PIXMA MG2140
item Canon PIXMA MG2150
item Canon PIXMA MG2160
item Canon PIXMA MG2170
item Canon PIXMA MG2180
item Canon MG2200 series
item Canon PIXMA MG2210
item Canon PIXMA MG2220
item Canon PIXMA MG2240
item Canon PIXMA MG2250
item Canon PIXMA MG2260
item Canon PIXMA MG2270
item Canon PIXMA MG2280
item Canon MG2400 series
item Canon PIXMA MG2400
item Canon PIXMA MG2410
item Canon PIXMA MG2420
item Canon PIXMA MG2440
item Canon PIXMA MG2450
item Canon PIXMA MG2460
item Canon PIXMA MG2470
item Canon PIXMA MG2490
item Canon MG2500 series
item Canon PIXMA MG2510
item Canon PIXMA MG2520
item Canon PIXMA MG2522
item Canon PIXMA MG2525
item Canon PIXMA MG2540
item Canon PIXMA MG2540S
item Canon PIXMA MG2545S
item Canon PIXMA MG2550
item Canon PIXMA MG2550S
item Canon PIXMA MG2555S
item Canon PIXMA MG2560
item Canon PIXMA MG2570
item Canon PIXMA MG2570S
item Canon PIXMA MG2580
item Canon PIXMA MG2580S
item Canon PIXMA MG2590
item Canon MG2900 series
item Canon PIXMA MG2910
item Canon PIXMA MG2920
item Canon PIXMA MG2922
item Canon PIXMA MG2924
item Canon PIXMA MG2940
item Canon PIXMA MG2950
item Canon PIXMA MG2960
item Canon PIXMA MG2970
item Canon PIXMA MG2980
item Canon PIXMA MG2990
item Canon MG3000 series
item Canon PIXMA MG3010
item Canon PIXMA MG3020
item Canon PIXMA MG3022
item Canon PIXMA MG3030
item Canon PIXMA MG3040
item Canon PIXMA MG3050
item Canon PIXMA MG3051
item Canon PIXMA MG3052
item Canon PIXMA MG3053
item Canon PIXMA MG3060
item Canon PIXMA MG3070
item Canon PIXMA MG3077
item Canon PIXMA MG3080
item Canon PIXMA MG3090
item Canon MG3100 series
item Canon PIXMA MG3100
item Canon PIXMA MG3110
item Canon PIXMA MG3120
item Canon PIXMA MG3122
item Canon PIXUS MG3130
item Canon PIXMA MG3140
item Canon PIXMA MG3150
item Canon PIXMA MG3160
item Canon PIXMA MG3170
item Canon PIXMA MG3180
item Canon MG3200 series
item Canon PIXMA MG3210
item Canon PIXMA MG3220
item Canon PIXMA MG3222
item Canon PIXUS MG3230
item Canon PIXMA MG3240
item Canon PIXMA MG3250
item Canon PIXMA MG3260
item Canon PIXMA MG3270
item Canon MG3500 series
item Canon PIXMA MG3510
item Canon PIXMA MG3520
item Canon PIXMA MG3522
item Canon PIXUS MG3530
item Canon PIXMA MG3540
item Canon PIXMA MG3550
item Canon PIXMA MG3560
item Canon PIXMA MG3570
item Canon PIXMA MG3580
item Canon MG3600 series
item Canon PIXMA MG3610
item Canon PIXMA MG3620
item Canon PIXUS MG3630
item Canon PIXMA MG3640
item Canon PIXMA MG3650
item Canon PIXMA MG3670
item Canon PIXMA MG3680
item Canon MG4100 series
item Canon PIXMA MG4100
item Canon PIXMA MG4110
item Canon PIXMA MG4120
item Canon PIXUS MG4130
item Canon PIXMA MG4140
item Canon PIXMA MG4150
item Canon PIXMA MG4160
item Canon PIXMA MG4170
item Canon PIXMA MG4180
item Canon MG4200 series
item Canon PIXMA MG4210
item Canon PIXMA MG4220
item Canon PIXUS MG4230
item Canon PIXMA MG4240
item Canon PIXMA MG4250
item Canon PIXMA MG4260
item Canon PIXMA MG4270
item Canon PIXMA MG4280
item Canon MG5100 series
item Canon PIXMA MG5100
item Canon PIXMA MG5120
item Canon PIXUS MG5130
item Canon PIXMA MG5140
item Canon PIXMA MG5150
item Canon PIXMA MG5170
item Canon PIXMA MG5180
item Canon MG5200 series
item Canon PIXMA MG5200
item Canon PIXMA MG5210
item Canon PIXMA MG5220
item Canon PIXUS MG5230
item Canon PIXMA MG5240
item Canon PIXMA MG5250
item Canon PIXMA MG5270
item Canon PIXMA MG5280
item Canon MG5300 series
item Canon PIXMA MG5300
item Canon PIXMA MG5310
item Canon PIXMA MG5320
item Canon PIXUS MG5330
item Canon PIXMA MG5340
item Canon PIXMA MG5350
item Canon PIXMA MG5370
item Canon PIXMA MG5380
item Canon MG5400 series
item Canon PIXMA MG5410
item Canon PIXMA MG5420
item Canon PIXMA MG5422
item Canon PIXUS MG5430
item Canon PIXMA MG5440
item Canon PIXMA MG5450
item Canon PIXMA MG5460
item Canon PIXMA MG5470
item Canon PIXMA MG5480
item Canon MG5500 series
item Canon PIXMA MG5510
item Canon PIXMA MG5520
item Canon PIXMA MG5522
item Canon PIXUS MG5530
item Canon PIXMA MG5540
item Canon PIXMA MG5550
item Canon PIXMA MG5560
item Canon PIXMA MG5570
item Canon PIXMA MG5580
item Canon MG5600 series
item Canon PIXMA MG5610
item Canon PIXMA MG5620
item Canon PIXMA MG5622
item Canon PIXUS MG5630
item Canon PIXMA MG5640
item Canon PIXMA MG5650
item Canon PIXMA MG5660
item Canon PIXMA MG5670
item Canon Mommy Photo MG5670
item Canon PIXMA MG5680
item Canon MG5700 series
item Canon PIXMA MG5710
item Canon PIXMA MG5720
item Canon PIXMA MG5721
item Canon PIXMA MG5722
item Canon PIXUS MG5730
item Canon PIXMA MG5740
item Canon PIXMA MG5750
item Canon PIXMA MG5751
item Canon PIXMA MG5752
item Canon PIXMA MG5753
item Canon PIXMA MG5770
item Canon PIXMA MG5780
item Canon PIXMA MG5790
item Canon Mommy Photo MG5790
item Canon PIXMA MG5795
item Canon MG6100 series
item Canon PIXMA MG6100
item Canon PIXMA MG6110
item Canon PIXMA MG6120
item Canon PIXUS MG6130
item Canon PIXMA MG6140
item Canon PIXMA MG6150
item Canon PIXMA MG6170
item Canon PIXMA MG6180
item Canon MG6200 series
item Canon PIXMA MG6200
item Canon PIXMA MG6210
item Canon PIXMA MG6220
item Canon PIXUS MG6230
item Canon PIXMA MG6240
item Canon PIXMA MG6250
item Canon PIXMA MG6270
item Canon PIXMA MG6280
item Canon MG6300 series
item Canon PIXMA MG6310
item Canon PIXMA MG6320
item Canon PIXUS MG6330
item Canon PIXMA MG6340
item Canon PIXMA MG6350
item Canon PIXMA MG6360
item Canon PIXMA MG6370
item Canon PIXMA MG6380
item Canon MG6400 series
item Canon PIXMA MG6400
item Canon PIXMA MG6410
item Canon PIXMA MG6420
item Canon PIXMA MG6440
item Canon PIXMA MG6450
item Canon PIXMA MG6470
item Canon MG6500 series
item Canon PIXUS MG6530
item Canon MG6600 series
item Canon PIXMA MG6610
item Canon PIXMA MG6620
item Canon PIXMA MG6622
item Canon PIXMA MG6640
item Canon PIXMA MG6650
item Canon PIXMA MG6660
item Canon PIXMA MG6670
item Canon Mommy Photo MG6670
item Canon PIXMA MG6680
item Canon MG6700 series
item Canon PIXUS MG6730
item Canon MG6800 series
item Canon PIXMA MG6810
item Canon PIXMA MG6820
item Canon PIXMA MG6821
item Canon PIXMA MG6822
item Canon PIXMA MG6840
item Canon PIXMA MG6850
item Canon PIXMA MG6851
item Canon PIXMA MG6852
item Canon PIXMA MG6853
item Canon PIXMA MG6870
item Canon PIXMA MG6880
item Canon MG6900 series
item Canon PIXUS MG6930
item Canon MG7100 series
item Canon PIXMA MG7110
item Canon PIXMA MG7120
item Canon PIXUS MG7130
item Canon PIXMA MG7140
item Canon PIXMA MG7150
item Canon PIXMA MG7170
item Canon PIXMA MG7180
item Canon MG7500 series
item Canon PIXMA MG7510
item Canon PIXMA MG7520
item Canon PIXUS MG7530
item Canon PIXUS MG7530F
item Canon PIXMA MG7540
item Canon PIXMA MG7550
item Canon PIXMA MG7560
item Canon PIXMA MG7570
item Canon Mommy Photo MG7570
item Canon PIXMA MG7580
item Canon MG7700 series
item Canon PIXMA MG7710
item Canon PIXMA MG7720
item Canon PIXUS MG7730
item Canon PIXUS MG7730F
item Canon PIXMA MG7740
item Canon PIXMA MG7750
item Canon PIXMA MG7751
item Canon PIXMA MG7752
item Canon PIXMA MG7753
item Canon PIXMA MG7770
item Canon PIXMA MG7780
item Canon PIXMA MG7790
item Canon MG8100 series
item Canon PIXMA MG8100
item Canon PIXMA MG8120
item Canon PIXMA MG8120B
item Canon PIXUS MG8130
item Canon PIXMA MG8140
item Canon PIXMA MG8150
item Canon PIXMA MG8170
item Canon PIXMA MG8180
item Canon MG8200 series
item Canon PIXMA MG8200
item Canon PIXMA MG8220
item Canon PIXUS MG8230
item Canon PIXMA MG8240
item Canon PIXMA MG8250
item Canon PIXMA MG8270
item Canon PIXMA MG8280
item Canon MX300 series
item Canon PIXMA MX300
item Canon PIXMA MX308
item Canon MX310 series
item Canon PIXMA MX310
item Canon PIXMA MX318
item Canon MX320 series
item Canon PIXMA MX320
item Canon PIXMA MX328
item Canon MX330 series
item Canon PIXMA MX330
item Canon PIXMA MX338
item Canon MX340 series
item Canon PIXMA MX340
item Canon PIXMA MX347
item Canon PIXMA MX348
item Canon MX350 series
item Canon PIXMA MX350
item Canon PIXUS MX350
item Canon PIXMA MX357
item Canon PIXMA MX358
item Canon MX360 series
item Canon PIXMA MX360
item Canon PIXMA MX366
item Canon PIXMA MX368
item Canon MX370 series
item Canon PIXMA MX370
item Canon PIXMA MX371
item Canon PIXMA MX372
item Canon PIXMA MX374
item Canon PIXMA MX375
item Canon PIXMA MX376
item Canon PIXMA MX377
item Canon PIXMA MX378
item Canon MX390 series
item Canon PIXMA MX391
item Canon PIXMA MX392
item Canon PIXMA MX394
item Canon PIXMA MX395
item Canon PIXMA MX396
item Canon PIXMA MX397
item Canon PIXMA MX398
item Canon MX410 series
item Canon PIXMA MX410
item Canon PIXMA MX416
item Canon PIXMA MX418
item Canon MX420 series
item Canon PIXMA MX420
item Canon PIXUS MX420
item Canon PIXMA MX426
item Canon PIXMA MX428
item Canon MX430 series
item Canon PIXMA MX430
item Canon PIXMA MX431
item Canon PIXMA MX432
item Canon PIXMA MX434
item Canon PIXMA MX435
item Canon PIXMA MX436
item Canon PIXMA MX437
item Canon PIXMA MX438
item Canon PIXMA MX439
item Canon MX450 series
item Canon PIXMA MX451
item Canon PIXMA MX452
item Canon PIXMA MX454
item Canon PIXMA MX455
item Canon PIXMA MX456
item Canon PIXMA MX457
item Canon PIXMA MX458
item Canon PIXMA MX459
item Canon MX470 series
item Canon PIXMA MX471
item Canon PIXMA MX472
item Canon PIXMA MX474
item Canon PIXMA MX475
item Canon PIXMA MX476
item Canon PIXMA MX477
item Canon PIXMA MX478
item Canon PIXMA MX479
item Canon MX490 series
item Canon PIXMA MX490
item Canon PIXMA MX492
item Canon PIXMA MX494
item Canon PIXMA MX495
item Canon PIXMA MX496
item Canon PIXMA MX497
item Canon PIXMA MX498
item Canon PIXMA MX499
item Canon MX510 series
item Canon PIXMA MX510
item Canon PIXMA MX511
item Canon PIXMA MX512
item Canon PIXUS MX513
item Canon PIXMA MX514
item Canon PIXMA MX515
item Canon PIXMA MX516
item Canon PIXMA MX517
item Canon PIXMA MX518
item Canon MX520 series
item Canon PIXMA MX521
item Canon PIXMA MX522
item Canon PIXUS MX523
item Canon PIXMA MX524
item Canon PIXMA MX525
item Canon PIXMA MX526
item Canon PIXMA MX527
item Canon PIXMA MX528
item Canon MX530 series
item Canon PIXMA MX531
item Canon PIXMA MX532
item Canon PIXMA MX534
item Canon PIXMA MX535
item Canon PIXMA MX536
item Canon PIXMA MX537
item Canon PIXMA MX538
item Canon MX700 series
item Canon PIXMA MX700
item Canon MX710 series
item Canon PIXMA MX710
item Canon PIXMA MX711
item Canon PIXMA MX712
item Canon PIXMA MX714
item Canon PIXMA MX715
item Canon MX720 series
item Canon PIXMA MX721
item Canon PIXMA MX722
item Canon PIXMA MX725
item Canon PIXMA MX726
item Canon PIXMA MX727
item Canon PIXMA MX728
item Canon MX850 series
item Canon PIXMA MX850
item Canon PIXUS MX850
item Canon MX860 series
item Canon PIXMA MX860
item Canon PIXUS MX860
item Canon PIXMA MX868
item Canon MX870 series
item Canon PIXMA MX870
item Canon PIXUS MX870
item Canon PIXMA MX876
item Canon MX880 series
item Canon PIXMA MX880
item Canon PIXMA MX882
item Canon PIXUS MX883
item Canon PIXMA MX884
item Canon PIXMA MX885
item Canon PIXMA MX886
item Canon PIXMA MX888
item Canon MX890 series
item Canon PIXMA MX890
item Canon PIXMA MX892
item Canon PIXUS MX893
item Canon PIXMA MX894
item Canon PIXMA MX895
item Canon PIXMA MX897
item Canon PIXMA MX898
item Canon MX920 series
item Canon PIXMA MX922
item Canon PIXUS MX923
item Canon PIXMA MX924
item Canon PIXMA MX925
item Canon PIXMA MX926
item Canon PIXMA MX927
item Canon PIXMA MX928
item Canon MX7600 series
item Canon PIXMA MX7600
item Canon PIXUS MX7600
item Canon E400 series
item Canon PIXMA E400
item Canon PIXMA E401
item Canon PIXMA E404
item Canon PIXMA E408
item Canon PIXMA E409
item Canon E410 series
item Canon PIXMA E410
item Canon PIXMA E414
item Canon PIXMA E417
item Canon PIXMA E418
item Canon E460 series
item Canon PIXMA E460
item Canon PIXMA E461
item Canon PIXMA E464
item Canon PIXMA E468
item Canon E470 series
item Canon PIXMA E470
item Canon PIXMA E471
item Canon PIXMA E474
item Canon PIXMA E477
item Canon PIXMA E478
item Canon E480 series
item Canon PIXMA E480
item Canon PIXMA E481
item Canon PIXMA E484
item Canon PIXMA E488
item Canon PIXMA E489
item Canon E500 series
item Canon PIXMA E500
item Canon E510 series
item Canon PIXMA E510
item Canon PIXMA E514
item Canon PIXMA E518
item Canon E560 series
item Canon PIXMA E560
item Canon PIXMA E568
item Canon PIXMA E569
item Canon E600 series
item Canon PIXMA E600
item Canon PIXMA E608
item Canon E610 series
item Canon PIXMA E610
item Canon PIXMA E618
item Canon E3100 series
item Canon PIXMA E3170
item Canon G1000 series
item Canon PIXMA G1000
item Canon PIXMA G1100
item Canon PIXMA G1200
item Canon PIXMA G1400
item Canon PIXMA G1500
item Canon PIXMA G1800
item Canon PIXMA G1900
item Canon PIXMA G1910
item Canon G2000 series
item Canon PIXMA G2000
item Canon PIXMA G2002
item Canon PIXMA G2100
item Canon PIXMA G2200
item Canon PIXMA G2400
item Canon PIXMA G2500
item Canon PIXMA G2600
item Canon PIXMA G2800
item Canon PIXMA G2900
item Canon PIXMA G2910
item Canon PIXMA G2915
item Canon G3000 series
item Canon PIXMA G3000
item Canon PIXMA G3010
item Canon PIXMA G3100
item Canon PIXMA G3200
item Canon PIXMA G3400
item Canon PIXMA G3500
item Canon PIXMA G3600
item Canon PIXMA G3800
item Canon PIXMA G3900
item Canon PIXMA G3910
item Canon PIXMA G3915
item Canon G4000 series
item Canon PIXMA G4000
item Canon PIXMA G4010
item Canon PIXMA G4100
item Canon PIXMA G4200
item Canon PIXMA G4400
item Canon PIXMA G4500
item Canon PIXMA G4600
item Canon PIXMA G4800
item Canon PIXMA G4900
item Canon PIXMA G4902
item Canon PIXMA G4910
item Canon PIXMA G4911
item Canon PIXMA P200
item Canon TS3100 series
item Canon PIXMA TS3110
item Canon PIXMA TS3120
item Canon PIXMA TS3130
item Canon PIXMA TS3130S
item Canon PIXMA TS3140
item Canon PIXMA TS3150
item Canon PIXMA TS3160
item Canon PIXMA TS3170
item Canon PIXMA TS3190
item Canon PIXMA TS3195
item Canon TS5000 series
item Canon PIXMA TS5010
item Canon PIXMA TS5020
item Canon PIXMA TS5030
item Canon PIXMA TS5030S
item Canon PIXMA TS5040
item Canon PIXMA TS5050
item Canon PIXMA TS5051
item Canon PIXMA TS5053
item Canon PIXMA TS5055
item Canon PIXMA TS5060
item Canon PIXMA TS5070
item Canon PIXMA TS5080
item Canon PIXMA TS5090
item Canon TS6000 series
item Canon PIXMA TS6010
item Canon PIXMA TS6020
item Canon PIXMA TS6030
item Canon PIXMA TS6040
item Canon PIXMA TS6050
item Canon PIXMA TS6051
item Canon PIXMA TS6052
item Canon PIXMA TS6060
item Canon PIXMA TS6070
item Canon PIXMA TS6080
item Canon TS8000 series
item Canon PIXMA TS8010
item Canon PIXMA TS8020
item Canon PIXMA TS8030
item Canon PIXMA TS8040
item Canon PIXMA TS8050
item Canon PIXMA TS8051
item Canon PIXMA TS8052
item Canon PIXMA TS8053
item Canon PIXMA TS8060
item Canon PIXMA TS8070
item Canon PIXMA TS8080
item Canon PIXMA TS8090
item Canon TS9000 series
item Canon PIXMA TS9010
item Canon PIXMA TS9020
item Canon PIXMA TS9030
item Canon PIXMA TS9040
item Canon PIXMA TS9050
item Canon PIXMA TS9055
item Canon PIXMA TS9060
item Canon PIXMA TS9080
item Canon iB4000 series
item Canon MAXIFY iB4010
item Canon MAXIFY iB4020
item Canon MAXIFY iB4030
item Canon MAXIFY iB4040
item Canon MAXIFY iB4050
item Canon MAXIFY iB4060
item Canon MAXIFY iB4070
item Canon MAXIFY iB4080
item Canon MAXIFY iB4090
item Canon iB4100 series
item Canon MAXIFY iB4110
item Canon MAXIFY iB4120
item Canon MAXIFY iB4130
item Canon MAXIFY iB4140
item Canon MAXIFY iB4150
item Canon MAXIFY iB4170
item Canon MAXIFY iB4180
item Canon MAXIFY iB4190
item Canon MB2000 series
item Canon MAXIFY MB2010
item Canon MAXIFY MB2020
item Canon MAXIFY MB2030
item Canon MAXIFY MB2040
item Canon MAXIFY MB2050
item Canon MAXIFY MB2060
item Canon MB2100 series
item Canon MAXIFY MB2110
item Canon MAXIFY MB2120
item Canon MAXIFY MB2130
item Canon MAXIFY MB2140
item Canon MAXIFY MB2150
item Canon MAXIFY MB2160
item Canon MB2300 series
item Canon MAXIFY MB2320
item Canon MAXIFY MB2330
item Canon MAXIFY MB2340
item Canon MAXIFY MB2350
item Canon MAXIFY MB2360
item Canon MAXIFY MB2390
item Canon MB2700 series
item Canon MAXIFY MB2710
item Canon MAXIFY MB2720
item Canon MAXIFY MB2730
item Canon MAXIFY MB2740
item Canon MAXIFY MB2750
item Canon MAXIFY MB2760
item Canon MAXIFY MB2790
item Canon MB5000 series
item Canon MAXIFY MB5020
item Canon MAXIFY MB5030
item Canon MAXIFY MB5040
item Canon MAXIFY MB5050
item Canon MAXIFY MB5060
item Canon MAXIFY MB5070
item Canon MAXIFY MB5080
item Canon MAXIFY MB5090
item Canon MB5100 series
item Canon MAXIFY MB5110
item Canon MAXIFY MB5120
item Canon MAXIFY MB5130
item Canon MAXIFY MB5140
item Canon MAXIFY MB5150
item Canon MAXIFY MB5160
item Canon MAXIFY MB5170
item Canon MAXIFY MB5180
item Canon MAXIFY MB5190
item Canon MB5300 series
item Canon MAXIFY MB5310
item Canon MAXIFY MB5320
item Canon MAXIFY MB5330
item Canon MAXIFY MB5340
item Canon MAXIFY MB5350
item Canon MAXIFY MB5360
item Canon MAXIFY MB5370
item Canon MAXIFY MB5390
item Canon MB5400 series
item Canon MAXIFY MB5410
item Canon MAXIFY MB5420
item Canon MAXIFY MB5430
item Canon MAXIFY MB5440
item Canon MAXIFY MB5450
item Canon MAXIFY MB5460
item Canon MAXIFY MB5470
item Canon MAXIFY MB5480
item Canon MAXIFY MB5490
item Canon PIXUS 50i
item Canon PIXUS 80i
item Canon PIXUS 450i
item Canon PIXUS 455i
item Canon PIXUS 470PD
item Canon PIXUS 475PD
item Canon PIXUS 550i
item Canon PIXUS 560i
item Canon PIXUS 850i
item Canon PIXUS 860i
item Canon PIXUS 865R
item Canon PIXUS 900PD
item Canon PIXUS 950i
item Canon PIXUS 960i
item Canon PIXUS 990i
item Canon PIXUS 6100i
item Canon PIXUS 6500i
item Canon PIXUS 9100i
item Canon PIXUS 9900i
item Canon i70
item Canon i80
item Canon i450
item Canon i450X
item Canon i455
item Canon i455X
item Canon i470D
item Canon i475D
item Canon i550
item Canon i550X
item Canon i560
item Canon i560X
item Canon i850old
item Canon i850
item Canon i860old
item Canon i860
item Canon i865old
item Canon i865
item Canon i900D
item Canon i905D
item Canon i950
item Canon i960
item Canon i965
item Canon i990
item Canon i6100
item Canon i6500
item Canon i9100
item Canon i9900
item Canon i9950
item Epson Artisan 50
item Epson Artisan 700
item Epson Artisan 710
item Epson Artisan 800
item Epson Artisan 810
item Epson Artisan 835
item Epson Artisan 1430
item Epson B-300
item Epson B-308
item Epson B-310
item Epson B-310N
item Epson B-500DN
item Epson B-508DN
item Epson B-510DN
item Epson Expression ET-2550 EcoTank
item Epson Expression ET-2600 EcoTank
item Epson Expression ET-2650 EcoTank
item Epson Expression ET-2700 EcoTank
item Epson Expression ET-2750 EcoTank
item Epson Expression ET-2750 EcoTank Business Edition
item Epson Expression Home XP-240
item Epson Expression Home XP-245
item Epson Expression Home XP-340
item Epson Expression Home XP-344
item Epson Expression Home XP-440
item Epson Expression Home XP-442
item Epson Expression Home XP-820
item Epson Expression Photo XP-860
item Epson Expression Photo XP-960
item Epson Expression Photo XP-8500
item Epson XP-15000 Series
item Epson L120
item Epson L130
item Epson L210
item Epson L310
item Epson L1300
item Epson L1800
item Epson SC-P400 Series
item Epson SC-P600 Series
item Epson SC-P800 Series
item Epson SC-P6000 Series
item Epson SC-P7000 Series
item Epson SC-P8000 Series
item Epson SC-P9000 Series
item Epson SC-P10000 Series
item Epson SC-P20000 Series
item Epson Stylus C20
item Epson Stylus C20SX
item Epson Stylus C20UX
item Epson Stylus C40
item Epson Stylus C40SX
item Epson Stylus C40UX
item Epson Stylus C41
item Epson Stylus C41SX
item Epson Stylus C41UX
item Epson Stylus C42
item Epson Stylus C42SX
item Epson Stylus C42UX
item Epson Stylus C43
item Epson Stylus C43SX
item Epson Stylus C43UX
item Epson Stylus C44
item Epson Stylus C44SX
item Epson Stylus C44UX
item Epson Stylus C45
item Epson Stylus C46
item Epson Stylus C48
item Epson Stylus C50
item Epson Stylus C60
item Epson Stylus C61
item Epson Stylus C62
item Epson Stylus C63
item Epson Stylus C64
item Epson Stylus C65
item Epson Stylus C66
item Epson Stylus C68
item Epson Stylus C70
item Epson Stylus C79
item Epson Stylus C80
item Epson Stylus C82
item Epson Stylus C83
item Epson Stylus C84
item Epson Stylus C85
item Epson Stylus C86
item Epson Stylus C87
item Epson Stylus C88
item Epson Stylus C92
item Epson Stylus C110
item Epson Stylus C120
item Epson Stylus Color
item Epson Stylus Color I
item Epson Stylus Color II
item Epson Stylus Color IIs
item Epson Stylus Color PRO
item Epson Stylus Pro XL
item Epson Stylus Color 400
item Epson Stylus Color 440
item Epson Stylus Color 460
item Epson Stylus Color 480
item Epson Stylus Color 500
item Epson Stylus Color 580
item Epson Stylus Color 600
item Epson Stylus Color 640
item Epson Stylus Color 660
item Epson Stylus Color 670
item Epson Stylus Color 680
item Epson Stylus Color 740
item Epson Stylus Color 760
item Epson Stylus Color 777
item Epson Stylus Color 800
item Epson Stylus Color 850
item Epson Stylus Color 860
item Epson Stylus Color 880
item Epson Stylus Color 8 3
item Epson Stylus Color 900
item Epson Stylus Color 980
item Epson Stylus Color 1160
item Epson Stylus Color 1500
item Epson Stylus Color 1520
item Epson Stylus Color 3000
item Epson Stylus Office B30
item Epson Stylus Office B33
item Epson Stylus Office B40W
item Epson Stylus Office B42WD
item Epson Stylus Office B1100
item Epson Stylus Office T30
item Epson Stylus Office T33
item Epson Stylus Office T40W
item Epson Stylus Office T1100
item Epson Stylus Office T1110
item Epson Stylus Office BX300F
item Epson Stylus Office BX525WD
item Epson Stylus Office BX535WD
item Epson Stylus Office BX600FW
item Epson Stylus Office BX625FWD
item Epson Stylus Office BX630FW
item Epson Stylus Office BX635FWD
item Epson Stylus Office SX600FW
item Epson Stylus Office SX620FW
item Epson Stylus Office TX300F
item Epson Stylus Office TX600FW
item Epson Stylus Office TX620FWD
item Epson Stylus Photo
item Epson Stylus Photo 700
item Epson Stylus Photo EX
item Epson Stylus Photo EX3
item Epson Stylus Photo 720
item Epson Stylus Photo 750
item Epson Stylus Photo 780
item Epson Stylus Photo 785
item Epson Stylus Photo 790
item Epson Stylus Photo 810
item Epson Stylus Photo 820
item Epson Stylus Photo 825
item Epson Stylus Photo 830
item Epson Stylus Photo 830U
item Epson Stylus Photo 870
item Epson Stylus Photo 875
item Epson Stylus Photo 890
item Epson Stylus Photo 895
item Epson Stylus Photo 900
item Epson Stylus Photo 915
item Epson Stylus Photo 925
item Epson Stylus Photo 935
item Epson Stylus Photo 950
item Epson Stylus Photo 960
item Epson Stylus Photo 1200
item Epson Stylus Photo 1270
item Epson Stylus Photo 1280
item Epson Stylus Photo 1290
item Epson Stylus Photo 1290s
item Epson Stylus Photo 1400
item Epson Stylus Photo 1410
item Epson Stylus Photo 2000P
item Epson Stylus Photo 2100
item Epson Stylus Photo 2200
item Epson Stylus Photo P50
item Epson Stylus Photo R200
item Epson Stylus Photo R210
item Epson Stylus Photo R220
item Epson Stylus Photo R230
item Epson Stylus Photo R240
item Epson Stylus Photo R245
item Epson Stylus Photo R260
item Epson Stylus Photo R265
item Epson Stylus Photo R270
item Epson Stylus Photo R280
item Epson Stylus Photo R285
item Epson Stylus Photo R290
item Epson Stylus Photo R300
item Epson Stylus Photo R310
item Epson Stylus Photo R320
item Epson Stylus Photo R340
item Epson Stylus Photo R350
item Epson Stylus Photo R360
item Epson Stylus Photo R380
item Epson Stylus Photo R390
item Epson Stylus Photo R800
item Epson Stylus Photo R1800
item Epson Stylus Photo R1900
item Epson Stylus Photo R2000
item Epson Stylus Photo R2400
item Epson Stylus Photo R2880
item Epson Stylus Photo R3000
item Epson Stylus Photo RX400
item Epson Stylus Photo RX420
item Epson Stylus Photo RX425
item Epson Stylus Photo RX430
item Epson Stylus Photo RX500
item Epson Stylus Photo RX510
item Epson Stylus Photo RX560
item Epson Stylus Photo RX580
item Epson Stylus Photo RX585
item Epson Stylus Photo RX590
item Epson Stylus Photo RX595
item Epson Stylus Photo RX600
item Epson Stylus Photo RX610
item Epson Stylus Photo RX620
item Epson Stylus Photo RX630
item Epson Stylus Photo RX640
item Epson Stylus Photo RX650
item Epson Stylus Photo RX680
item Epson Stylus Photo RX685
item Epson Stylus Photo RX690
item Epson Stylus Photo RX700
item Epson Stylus Photo TX700W
item Epson Stylus Photo TX710W
item Epson Stylus Photo TX800FW
item Epson Stylus Photo TX810FW
item Epson Stylus Pro 3800
item Epson Stylus Pro 3880
item Epson Stylus Pro 3885
item Epson Stylus Pro 4000
item Epson Stylus Pro 4800/4880 Back Compatible
item Epson Stylus Pro 4800
item Epson Stylus Pro 4880
item Epson Stylus Pro 4900
item Epson Stylus Pro 5000
item Epson Stylus Pro 5500
item Epson Stylus Pro 7000
item Epson Stylus Pro 7500
item Epson Stylus Pro 7600
item Epson Stylus Pro 7700
item Epson Stylus Pro 7800
item Epson Stylus Pro 7880
item Epson Stylus Pro 7890
item Epson Stylus Pro 7900
item Epson Stylus Pro 9000
item Epson Stylus Pro 9500
item Epson Stylus Pro 9600
item Epson Stylus Pro 9700
item Epson Stylus Pro 9800
item Epson Stylus Pro 9880
item Epson Stylus Pro 9890
item Epson Stylus Pro 9900
item Epson Stylus Pro 10000
item Epson Stylus Pro 11800/11880 Back Compatible
item Epson Stylus Pro 11800
item Epson Stylus Pro 11880
item Epson Stylus Scan 2000
item Epson Stylus Scan 2500
item Epson Stylus CX1500
item Epson Stylus CX3100
item Epson Stylus CX3200
item Epson Stylus CX3500
item Epson Stylus CX3600
item Epson Stylus CX3650
item Epson Stylus CX3700
item Epson Stylus CX3800
item Epson Stylus CX3805
item Epson Stylus CX3810
item Epson Stylus CX3900
item Epson Stylus CX4100
item Epson Stylus CX4200
item Epson Stylus CX4400
item Epson Stylus CX4500
item Epson Stylus CX4600
item Epson Stylus CX4700
item Epson Stylus CX4800
item Epson Stylus CX4900
item Epson Stylus CX5000
item Epson Stylus CX5000F
item Epson Stylus CX5100
item Epson Stylus CX5200
item Epson Stylus CX5300
item Epson Stylus CX5400
item Epson Stylus CX5500
item Epson Stylus CX5600
item Epson Stylus CX5700
item Epson Stylus CX5800
item Epson Stylus CX6000
item Epson Stylus CX6300
item Epson Stylus CX6400
item Epson Stylus CX6500
item Epson Stylus CX6600
item Epson Stylus CX7000F
item Epson Stylus CX7300
item Epson Stylus CX7400
item Epson Stylus CX7700
item Epson Stylus CX7800
item Epson Stylus CX8300
item Epson Stylus CX8400
item Epson Stylus CX9300F
item Epson Stylus CX9400
item Epson Stylus CX9400F
item Epson Stylus CX9475F
item Epson Stylus D68
item Epson Stylus D78
item Epson Stylus D88
item Epson Stylus D92
item Epson Stylus D120
item Epson Stylus DX3800
item Epson Stylus DX3850
item Epson Stylus DX4000
item Epson Stylus DX4050
item Epson Stylus DX4200
item Epson Stylus DX4250
item Epson Stylus DX4400
item Epson Stylus DX4450
item Epson Stylus DX4800
item Epson Stylus DX4850
item Epson Stylus DX7000F
item Epson Stylus DX7400
item Epson Stylus DX7450
item Epson Stylus DX8400
item Epson Stylus DX8450
item Epson Stylus DX9400F
item Epson Stylus NX100
item Epson Stylus NX105
item Epson Stylus NX115
item Epson Stylus NX200
item Epson Stylus NX215
item Epson Stylus NX300
item Epson Stylus NX400
item Epson Stylus NX415
item Epson Stylus NX420
item Epson Stylus NX515
item Epson Stylus NX530
item Epson Stylus NX625
item Epson Stylus NX630
item Epson Stylus NX635
item Epson Stylus NX645
item Epson Stylus Photo PX650
item Epson Stylus Photo PX700W
item Epson Stylus Photo PX710W
item Epson Stylus Photo PX800FW
item Epson Stylus Photo PX810FW
item Epson Stylus S20
item Epson Stylus S21
item Epson Stylus S50
item Epson Stylus SX100
item Epson Stylus SX105
item Epson Stylus SX110
item Epson Stylus SX115
item Epson Stylus SX200
item Epson Stylus SX205
item Epson Stylus SX210
item Epson Stylus SX215
item Epson Stylus SX400
item Epson Stylus SX405
item Epson Stylus SX410
item Epson Stylus SX415
item Epson Stylus SX420
item Epson Stylus SX445W
item Epson Stylus SX510W
item Epson Stylus SX515
item Epson Stylus SX525
item Epson Stylus SX535FW
item Epson Stylus SX600FW
item Epson Stylus SX610FW
item Epson Stylus SX615
item Epson Stylus SX630
item Epson Stylus SX635
item Epson Stylus SX645
item Epson Stylus SX650
item Epson Stylus T13
item Epson Stylus T20
item Epson Stylus T21
item Epson Stylus T22
item Epson Stylus T22E
item Epson Stylus T26
item Epson Stylus T30
item Epson Stylus T40W
item Epson Stylus T42WD
item Epson Stylus T50
item Epson Stylus T59
item Epson Stylus T60
item Epson Stylus TX100
item Epson Stylus TX101
item Epson Stylus TX102
item Epson Stylus TX103
item Epson Stylus TX104
item Epson Stylus TX105
item Epson Stylus TX106
item Epson Stylus TX109
item Epson Stylus TX110
item Epson Stylus TX125
item Epson Stylus TX200
item Epson Stylus TX210
item Epson Stylus TX300F
item Epson Stylus TX400
item Epson Stylus TX410
item Epson Stylus TX420
item Epson Stylus TX510FN
item Epson Stylus TX550W
item Epson Stylus TX560WD
item Epson Stylus TX610FW
item Epson Stylus TX615
item Epson Stylus TX630
item Epson Stylus TX635
item Epson Stylus TX645
item Epson Stylus TX650
item Epson Stylus TX659
item Epson Stylus XP100
item Epson SureColor P400
item Epson SureColor P600
item Epson SureColor P800
item Epson SureColor P6000
item Epson SureColor P7000
item Epson SureColor P7000 Commercial Edition
item Epson SureColor P8000
item Epson SureColor P9000
item Epson SureColor P9000 Commercial Edition
item Epson SureColor P10000
item Epson SureColor P20000
item Epson PictureMate
item Epson PictureMate Dash
item Epson PictureMate Deluxe
item Epson PictureMate Flash
item Epson PictureMate Pal
item Epson PictureMate Snap
item Epson PictureMate 100
item Epson PictureMate 200
item Epson PictureMate 210
item Epson PictureMate 215
item Epson PictureMate 240
item Epson PictureMate 250
item Epson PictureMate 260
item Epson PictureMate 270
item Epson PictureMate 280
item Epson PictureMate 290
item Epson PictureMate 500
item Epson PictureMate 2005
item Epson WorkForce 30
item Epson WorkForce 40
item Epson WorkForce 60
item Epson WorkForce 310
item Epson WorkForce 315
item Epson WorkForce 500
item Epson WorkForce 545
item Epson WorkForce 600
item Epson WorkForce 610
item Epson WorkForce 615
item Epson WorkForce 625
item Epson WorkForce 630
item Epson WorkForce 633
item Epson WorkForce 635
item Epson WorkForce 645
item Epson WorkForce 1100
item Epson WF-7010 Series
item Epson WF-7011 Series
item Epson WF-7015 Series
item Epson WF-7018 Series
item Epson WF-7510 Series
item Epson WF-7511 Series
item Epson WF-7515 Series
item Epson WF-7520 Series
item Epson WF-7521 Series
item Epson WF-7525 Series
item Epson CL 700
item Epson CL 750
item Epson CL 760
item Epson E 100
item Epson E 150
item Epson E 200
item Epson E 300
item Epson E 500
item Epson E 520
item Epson E 700
item Epson E 720
item Epson EM 900C
item Epson EM 930C
item Epson EP 302
item Epson EP 702A
item Epson EP 801A
item Epson EP 901A
item Epson EP 901F
item Epson MC 2000
item Epson MC 5000
item Epson MC 7000
item Epson MC 9000
item Epson MC 10000
item Epson ME 300
item Epson ME 320
item Epson ME Office 70
item Epson ME Office 80W
item Epson ME Office 82WD
item Epson ME Office 85ND
item Epson ME Office 360
item Epson ME Office 600F
item Epson ME Office 620F
item Epson ME Office 700FW
item Epson ME Office 900WD
item Epson ME Office 940FW
item Epson ME Office 960FWD
item Epson ME Office 1100
item Epson MJ 930C
item Epson MJ 5100C
item Epson MJ 6000C
item Epson MJ 8000C
item Epson PM 670C
item Epson PM 700C
item Epson PM 730C
item Epson PM 740C
item Epson PM 750C
item Epson PM 760C
item Epson PM 770C
item Epson PM 780C
item Epson PM 790PT
item Epson PM 800C
item Epson PM 850PT
item Epson PM 870C
item Epson PM 880C
item Epson PM 930C
item Epson PM 940C
item Epson PM 950C
item Epson PM 970C
item Epson PM 980C
item Epson PM 2000C
item Epson PM 2200C
item Epson PM 3000C
item Epson PM 3300C
item Epson PM 3500C
item Epson PM 3700C
item Epson PM 4000PX
item Epson PM 5000C
item Epson PM 7000C
item Epson PM 9000C
item Epson PM 10000
item Epson PM A650
item Epson PM A750
item Epson PM A820
item Epson PM A890
item Epson PM A900
item Epson PM A940
item Epson PM A950
item Epson PM D600
item Epson PM D750
item Epson PM D770
item Epson PM D800
item Epson PM D870
item Epson PM D1000
item Epson PM G700
item Epson PM G720
item Epson PM G730
item Epson PM G800
item Epson PM G820
item Epson PM G850
item Epson PM T960
item Epson PM G4500
item Epson PX A650
item Epson Offirio PX B300
item Epson Offirio PX B500
item Epson PX 7V
item Epson PX 101
item Epson PX 201
item Epson PX 203
item Epson PX 204
item Epson PX 401A
item Epson PX 503A
item Epson PX 504A
item Epson PX 601F
item Epson PX 603F
item Epson PX 1001
item Epson PX 1200
item Epson PX 1600F
item Epson PX 1700F
item Epson PX G900
item Epson PX G920
item Epson PX G5000
item Epson PX G5300
item Epson PX V500
item Epson PX V600
item Epson PX V630
item Epson PX V780
item Epson PX 5500
item Epson PX G5600
item Epson PX 7000
item Epson PX 9000
item Apollo P-2100
item Apollo P-2150
item Apollo P-2200
item Apollo P-2250
item Apollo P-2500
item Apollo P-2550
item Apollo P-2600
item Apollo P-2650
item Apple Color StyleWriter 4100
item Apple Color StyleWriter 4500
item Apple Color StyleWriter 6500
item Apple LaserWriter Select 360
item Brother DCP-1200
item Brother DCP-8045D
item Brother HL-1040
item Brother HL-1050
item Brother HL-1060
item Brother HL-1070
item Brother HL-10V
item Brother HL-10h
item Brother HL-1240
item Brother HL-1250
item Brother HL-1260
item Brother HL-1270N
item Brother HL-1440
item Brother HL-1450
item Brother HL-1470N
item Brother HL-1650
item Brother HL-1660e
item Brother HL-1670N
item Brother HL-1850
item Brother HL-1870N
item Brother HL-2060
item Brother HL-2250DN
item Brother HL-2400CeN
item Brother HL-2460
item Brother HL-2460N
item Brother HL-2600CN
item Brother HL-3400CN
item Brother HL-3450CN
item Brother HL-4Ve
item Brother HL-4040CN
item Brother HL-5030
item Brother HL-5040
item Brother HL-5050
item Brother HL-5070N
item Brother HL-5140
item Brother HL-5150D
item Brother HL-5170DN
item Brother HL-5340D
item Brother HL-630
item Brother HL-660
item Brother HL-7050
item Brother HL-7050N
item Brother HL-760
item Brother HL-960
item Brother MFC-6550MC
item Brother MFC-8300
item Brother MFC-9500
item Brother MFC-9600
item Canon GP 335
item Canon LBP-4sx
item Canon LBP-430
item Canon LBP-1000
item Canon LBP-1260
item Canon LBP-1760
item Canon LBP-3360
item Canon LBP-5360
item Canon LBP-5390
item Canon imageRunner 330s
item Canon imageRunner C2550
item Canon imageRunner C2570
item Canon imageRunner C2570i
item Canon imageRunner C2570N
item Canon imageRunner C2620N
item Canon imageRunner C3100
item Canon imageRunner C3170
item Canon imageRunner C3170i
item Canon imageRunner C3200
item Canon imageRunner C5030
item Canon imageRunner C5058
item Canon imageRunner C5068
item Canon imageRunner C5180
item Canon imageRunner C5185
item Canon imageRunner C5185i
item Canon imageRunner C5800
item Canon imageRunner C5870U
item Canon imageRunner C6800
item Canon imageRunner C6870U
item Citizen ProJet II
item Datamax-ONeil p1115
item Datamax-ONeil p1115s
item Datamax-ONeil p1120n
item Datamax-ONeil p1125
item Datamax-ONeil p1725
item Datamax-ONeil w1110
item Datamax-ONeil H8308p
item DEC 1800
item DEC LN17
item Dell 3000cn
item Dell 3100cn
item Epson ActionLaser 1100
item Epson ActionLaser II
item Epson AL-C2000
item Epson AL-C2000 PS3
item Epson AL-C8500
item Epson AL-C8500PS
item Epson AL-C8600
item Epson AL-C8600 PS3
item Epson EPL-5200
item Epson EPL-5200+
item Epson EPL-5700
item Epson EPL-5700PS
item Epson EPL-5800
item Epson EPL-5800PS
item Epson EPL-5900
item Epson EPL-5900 PS3
item Epson EPL-6100
item Epson EPL-6100 PS3
item Epson EPL-7100
item Epson EPL-N2050
item Epson EPL-N2050+
item Epson EPL-N2050PS
item Epson EPL-N2050PS+
item Epson EPL-N2120
item Epson EPL-N2500
item Epson EPL-N2500 PS3
item Epson EPL-N2750
item Epson EPL-N2750PS
item Fujitsu PrintPartner 10V
item Fujitsu PrintPartner 16DV
item Fujitsu PrintPartner 20W
item Fujitsu PrintPartner 8000
item Generic PCL 4 Printer
item Generic PCL 4 Printer wide margin
item Generic PCL 4 LF Printer
item Generic PCL 5 Printer
item Generic PCL 5 Printer wide margin
item Generic PCL 5 LF Printer
item Generic PCL 5c Printer
item Generic PCL 5c LF Printer
item Generic PCL 5e Printer
item Generic PCL 5e LF Printer
item Generic PCL 6/PCL XL Printer
item Generic PCL 6/PCL XL LF Printer
item Generic PCL 6 Printer wide margin
item Generic PCL 6 LF Printer wide margin
item Generic PCL 6 Tabl Printer wide margin
item Generic PCL Color Laser
item Generic PCL Color Laser LF Printer
item Generic PCL Color wide margin
item Generic PCL Color LF wide margin
item Generic PCL Color Tabl wide margin
item Gestetner 10512
item Gestetner 2212
item Gestetner 2712
item Gestetner 3212
item Gestetner 3502
item Gestetner 3532/4235g
item Gestetner 4502
item Gestetner 4532/4245g
item Gestetner 6002
item Gestetner 7502
item Gestetner 9002
item Gestetner CS555
item Gestetner DSc1020
item Gestetner DSc1025
item Gestetner DSc1030
item Gestetner DSc1045
item Gestetner DSc1060
item Gestetner DSc1120
item Gestetner DSc1220
item Gestetner DSc1225
item Gestetner DSc1230
item Gestetner DSc1245
item Gestetner DSc1260
item Gestetner DSc424
item Gestetner DSc428
item Gestetner DSc432
item Gestetner DSc435
item Gestetner DSc445
item Gestetner DSc460
item Gestetner DSm415
item Gestetner DSm615
item Gestetner DSm616
item Gestetner DSm618
item Gestetner DSm618d
item Gestetner DSm620
item Gestetner DSm620d
item Gestetner DSm622
item Gestetner DSm627
item Gestetner DSm635/635G
item Gestetner DSm645/645G
item Gestetner DSm651
item Gestetner DSm660
item Gestetner DSm675
item Gestetner DSm725
item Gestetner DSm730
item Gestetner DSm735/735G
item Gestetner DSm745/745G
item Gestetner MP1100/DSm7110
item Gestetner MP1350/DSm7135
item Gestetner MP1600/DSm716
item Gestetner MP2000/DSm721d
item Gestetner MP2500/DSm625
item Gestetner MP3500/DSm735e
item Gestetner MP4500/DSm745e
item Gestetner MP5500/DSm755
item Gestetner MP6500/DSm765
item Gestetner MP7500/DSm775
item Gestetner MP9000/DSm790
item Gestetner MP 161/DSm416
item Gestetner MP 2510/DSm725e
item Gestetner MP 2550
item Gestetner MP 2550B
item Gestetner MP 3010/DSm730e
item Gestetner MP 3350
item Gestetner MP 3350B
item Gestetner MP 4000
item Gestetner MP 4000B
item Gestetner MP 5000
item Gestetner MP 5000B
item Gestetner MPC1500/GS106
item Gestetner MPC2500/DSc525
item Gestetner MPC3000/DSc530
item Gestetner MPC3500/DSc535
item Gestetner MPC4500/DSc545
item Gestetner MP C2003
item Gestetner MP C2004
item Gestetner MP C2011
item Gestetner MP C2050
item Gestetner MP C2051
item Gestetner MP C2503
item Gestetner MP C2504
item Gestetner MP C2550
item Gestetner MP C2551
item Gestetner MP C2800
item Gestetner MP C300
item Gestetner MP C3001
item Gestetner MP C3002
item Gestetner MP C3003
item Gestetner MP C3004
item Gestetner MP C300SR
item Gestetner MP C3300
item Gestetner MP C3501
item Gestetner MP C3502
item Gestetner MP C3503
item Gestetner MP C3504
item Gestetner MP C400
item Gestetner MP C4000
item Gestetner MP C400SR
item Gestetner MP C4501
item Gestetner MP C4501A
item Gestetner MP C4502
item Gestetner MP C4502A
item Gestetner MP C4503
item Gestetner MP C4504
item Gestetner MP C5000
item Gestetner MP C5501
item Gestetner MP C5501A
item Gestetner MP C5502
item Gestetner MP C5502A
item Gestetner MP C5503
item Gestetner MP C6000
item Gestetner MP C6003
item Gestetner MP C6004
item Gestetner MP C6501
item Gestetner MP C6502
item Gestetner MP C6503
item Gestetner MP C7500
item Gestetner MP C7501
item Gestetner MP C8002
item Gestetner MP C8003
item Gestetner Pro C5200S
item Gestetner Pro C5210S
item HP Business Inkjet 2200
item HP Business Inkjet 2230
item HP Business Inkjet 2250
item HP Business Inkjet 2250TN
item HP Business Inkjet 2280
item HP Color Inkjet Printer CP1160
item HP Color Inkjet Printer CP1700
item HP Color LaserJet 2500
item HP Color LaserJet 3000
item HP Color LaserJet 3000n
item HP Color LaserJet 3000dn
item HP Color LaserJet 3000dtn
item HP Color LaserJet 3700
item HP Color LaserJet 3700n
item HP Color LaserJet 3800
item HP Color LaserJet 3800n
item HP Color LaserJet 3800dn
item HP Color LaserJet 3800dtn
item HP Color LaserJet 4500
item HP Color LaserJet 4550
item HP Color LaserJet 4600
item HP Color LaserJet 4610
item HP Color LaserJet 4650
item HP Color LaserJet 4700
item HP Color LaserJet 4700n
item HP Color LaserJet 4700dn
item HP Color LaserJet 4700dtn
item HP Color LaserJet 4700ph+
item HP Color LaserJet 5
item HP Color LaserJet 5m
item HP Color LaserJet 5000
item HP Color LaserJet 5500
item HP Color LaserJet 5500n
item HP Color LaserJet 5500dn
item HP Color LaserJet 5500dtn
item HP Color LaserJet 5500hdn
item HP Color LaserJet 8500
item HP Color LaserJet 8500n
item HP Color LaserJet 8500dn
item HP Color LaserJet 8550
item HP Color LaserJet 8550DN
item HP Color LaserJet 8550GN
item HP Color LaserJet 8550MN
item HP Color LaserJet 9500
item HP Color LaserJet 9500n
item HP Color LaserJet 9500hdn
item HP Color LaserJet 9500gp
item HP Color LaserJet CM1312
item HP Color LaserJet CM1312nfi
item HP Color LaserJet CM1411fn
item HP Color LaserJet CM1412fn
item HP Color LaserJet CM1413fn
item HP Color LaserJet CM1415fn
item HP Color LaserJet CM1415fnw
item HP Color LaserJet CM1416fnw
item HP Color LaserJet CM1417fnw
item HP Color LaserJet CM1418fnw
item HP Color LaserJet CM2320 MFP
item HP Color LaserJet CM2320FXI MFP
item HP Color LaserJet CM2320N MFP
item HP Color LaserJet CM2320NF MFP
item HP Color LaserJet CM3530 MFP
item HP Color LaserJet CM4540 MFP
item HP Color LaserJet CM4730 MFP
item HP Color LaserJet CM6030 MFP
item HP Color LaserJet CM6040 MFP
item HP Color LaserJet CM6040f MFP
item HP Color LaserJet CM6049f MFP
item HP Color LaserJet CP1514n
item HP Color LaserJet CP1515n
item HP Color LaserJet CP1518ni
item HP Color LaserJet CP2025
item HP Color LaserJet CP2025dn
item HP Color LaserJet CP2025n
item HP Color LaserJet CP2025x
item HP Color LaserJet CP3505
item HP Color LaserJet CP3505dn
item HP Color LaserJet CP3505n
item HP Color LaserJet CP3505x
item HP Color LaserJet CP3525
item HP Color LaserJet CP3525dn
item HP Color LaserJet CP3525n
item HP Color LaserJet CP3525x
item HP Color LaserJet CP4005
item HP Color LaserJet CP4005dn
item HP Color LaserJet CP4005n
item HP Color LaserJet CP4020
item HP Color LaserJet CP4500
item HP Color LaserJet CP4520
item HP Color LaserJet CP4540 MFP
item HP Color LaserJet CP5225
item HP Color LaserJet CP5225dn
item HP Color LaserJet CP5225n
item HP Color LaserJet CP5520
item HP Color LaserJet CP6015dn
item HP Color LaserJet CP6015de
item HP Color LaserJet CP6015n
item HP Color LaserJet CP6015x
item HP Color LaserJet CP6015xh
item HP DesignJet 230
item HP DesignJet 250C
item HP DesignJet 430
item HP DesignJet 450C
item HP DesignJet 455CA
item HP DesignJet 488CA
item HP DesignJet 700
item HP DesignJet 750C Plus
item HP DesignJet 750C
item HP DesignJet 2500CP
item HP DesignJet 3500CP
item HP DesignJet ColorPro CAD
item HP DeskJet 400
item HP DeskJet 420C
item HP DeskJet 450
item HP DeskJet 500
item HP DeskJet 500C
item HP DeskJet 505J Plus
item HP DeskJet 510
item HP DeskJet 520
item HP DeskJet 540C
item HP DeskJet 550C
item HP DeskJet 5550
item HP DeskJet 5551
item HP DeskJet 560C
item HP DeskJet 600
item HP DeskJet 600C
item HP DeskJet 610C
item HP DeskJet 610CL
item HP DeskJet 6122
item HP DeskJet 6127
item HP DeskJet 612C
item HP DeskJet 640C
item HP DeskJet 648C
item HP DeskJet 660C
item HP DeskJet 670C
item HP DeskJet 670TV
item HP DeskJet 672C
item HP DeskJet 680C
item HP DeskJet 682C
item HP DeskJet 690C
item HP DeskJet 692C
item HP DeskJet 693C
item HP DeskJet 694C
item HP DeskJet 695C
item HP DeskJet 697C
item HP DeskJet 810C
item HP DeskJet 812C
item HP DeskJet 815C
item HP DeskJet 816C
item HP DeskJet 825C
item HP DeskJet 830C
item HP DeskJet 832C
item HP DeskJet 840C
item HP DeskJet 841C
item HP DeskJet 842C
item HP DeskJet 843C
item HP DeskJet 845C
item HP DeskJet 850C
item HP DeskJet 855C
item HP DeskJet 870C
item HP DeskJet 880C
item HP DeskJet 882C
item HP DeskJet 890C
item HP DeskJet 895C
item HP DeskJet 916C
item HP DeskJet 920C
item HP DeskJet 9300
item HP DeskJet 930C
item HP DeskJet 932C
item HP DeskJet 933C
item HP DeskJet 934C
item HP DeskJet 935C
item HP DeskJet 940C
item HP DeskJet 948C
item HP DeskJet 950C
item HP DeskJet 952C
item HP DeskJet 955C
item HP DeskJet 957C
item HP DeskJet 959C
item HP DeskJet 960C
item HP DeskJet 970C
item HP DeskJet 975C
item HP DeskJet 980C
item HP DeskJet 990C
item HP DeskJet 995C
item HP DeskJet 1100C
item HP DeskJet 1120C
item HP DeskJet 1125C
item HP DeskJet 1200C
item HP DeskJet 1220C
item HP DeskJet 1600C
item HP DeskJet 1600CM
item HP DeskJet 2000
item HP DeskJet 2500
item HP DeskJet 2500CM
item HP DeskJet 340C
item HP DeskJet 3810
item HP DeskJet 3816
item HP DeskJet 3820
item HP DeskJet 3822
item HP LaserJet 2
item HP LaserJet 2D
item HP LaserJet 2P Plus
item HP LaserJet 2P
item HP LaserJet 3
item HP LaserJet 3D
item HP LaserJet 3P w/ PCL5
item HP LaserJet 3P w/PS
item HP LaserJet 4 Plus
item HP LaserJet 4
item HP LaserJet 4L
item HP LaserJet 4M
item HP LaserJet 4ML
item HP LaserJet 4P
item HP LaserJet 4Si
item HP LaserJet 4V
item HP LaserJet 5
item HP LaserJet 5L
item HP LaserJet 5M
item HP LaserJet 5MP
item HP LaserJet 5N
item HP LaserJet 5P
item HP LaserJet 5Si
item HP LaserJet 6
item HP LaserJet 6L
item HP LaserJet 6MP
item HP LaserJet 6P
item HP LaserJet 1010
item HP LaserJet 1012
item HP LaserJet 1015
item HP LaserJet 1022
item HP LaserJet 1100
item HP LaserJet 1100A
item HP LaserJet 1150
item HP LaserJet 1160
item HP LaserJet 1200
item HP LaserJet 1220
item HP LaserJet 1300
item HP LaserJet 1320
item HP LaserJet 2100
item HP LaserJet 2100M
item HP LaserJet 2200
item HP LaserJet 2300
item HP LaserJet 2410
item HP LaserJet 2420
item HP LaserJet 2430
item HP LaserJet 3015
item HP LaserJet 3020
item HP LaserJet 3030
item HP LaserJet 3050
item HP LaserJet 3052
item HP LaserJet 3055
item HP LaserJet 3200
item HP LaserJet 3200m
item HP LaserJet 3200se
item HP LaserJet 3300 MFP
item HP LaserJet 3310 MFP
item HP LaserJet 3320 MFP
item HP LaserJet 3320N MFP
item HP LaserJet 3330 MFP
item HP LaserJet 3380
item HP LaserJet 3390
item HP LaserJet 3392
item HP LaserJet 4000
item HP LaserJet 4050
item HP LaserJet 4100
item HP LaserJet 4200
item HP LaserJet 4240
item HP LaserJet 4250
item HP LaserJet 4300
item HP LaserJet 4345 mfp
item HP LaserJet 4350
item HP LaserJet 5000
item HP LaserJet 5100
item HP LaserJet 5200
item HP LaserJet 5200L
item HP LaserJet 8000
item HP LaserJet 8100
item HP LaserJet 8150
item HP LaserJet 9000
item HP LaserJet 9040
item HP LaserJet 9040 MFP
item HP LaserJet 9050
item HP LaserJet 9050 MFP
item HP LaserJet M3027 MFP
item HP LaserJet M3035 MFP
item HP LaserJet M4345 MFP
item HP LaserJet M5025 MFP
item HP LaserJet M5035 MFP
item HP LaserJet P2010
item HP LaserJet P2015
item HP LaserJet P3004
item HP LaserJet P3005
item HP Mopier 240
item HP Mopier 320
item HP OfficeJet 300
item HP OfficeJet 330
item HP OfficeJet 350
item HP OfficeJet 500
item HP OfficeJet 520
item HP OfficeJet 570
item HP OfficeJet 580
item HP OfficeJet 590
item HP OfficeJet 600
item HP OfficeJet 610
item HP OfficeJet 625
item HP OfficeJet 630
item HP OfficeJet 635
item HP OfficeJet 700
item HP OfficeJet 710
item HP OfficeJet 720
item HP OfficeJet 725
item HP OfficeJet 5105
item HP OfficeJet 5110
item HP OfficeJet 5110xi
item HP OfficeJet 6105
item HP OfficeJet 6110
item HP OfficeJet 7110
item HP OfficeJet 7130
item HP OfficeJet 7140
item HP OfficeJet D125
item HP OfficeJet D135
item HP OfficeJet D145
item HP OfficeJet D155
item HP OfficeJet G55
item HP OfficeJet G85
item HP OfficeJet G95
item HP OfficeJet K60
item HP OfficeJet K60xi
item HP OfficeJet K80
item HP OfficeJet K80xi
item HP OfficeJet LX
item HP OfficeJet Pro 1150C
item HP OfficeJet Pro 1170C
item HP OfficeJet Pro 1175C
item HP OfficeJet R40
item HP OfficeJet R45
item HP OfficeJet R60
item HP OfficeJet R65
item HP OfficeJet R80
item HP OfficeJet T45
item HP OfficeJet T65
item HP OfficeJet V40
item HP OfficeJet V40xi
item HP OfficeJet
item HP PSC 370
item HP PSC 380
item HP PSC 500
item HP PSC 750
item HP PSC 950
item HP PSC 950xi
item HP PSC 2110
item HP PSC 2150
item HP PSC 2210
item HP PhotoSmart 7150
item HP PhotoSmart 7345
item HP PhotoSmart 7350
item HP PhotoSmart 7550
item HP PhotoSmart P100
item HP PhotoSmart P130
item HP PhotoSmart P230
item HP PhotoSmart P1000
item HP PhotoSmart P1100
item HP PhotoSmart P1115
item HP PhotoSmart P1215
item HP PhotoSmart P1218
item HP PhotoSmart P1315
item HP e-printer e20
item IBM 4019
item IBM 4029 030 LaserPrinter 10
item IBM 4312
item IBM Infoprint 12
item IBM Page Printer 3112
item Infotec 4353 MF
item Infotec 4452 MF
item Infotec 4651 MF
item Infotec IS2022
item Infotec IS2027
item Infotec IS2032
item Infotec IS2035
item Infotec IS2045
item Infotec IS2090
item Infotec IS2105
item Infotec IS 2015
item Infotec IS 2018
item Infotec IS 2018D
item Infotec IS 2060
item Infotec IS 2075
item Infotec IS 2122
item Infotec IS 2127
item Infotec IS 2132
item Infotec IS 2135
item Infotec IS 2145
item Infotec IS 2151
item Infotec IS 2160
item Infotec IS 2175
item Infotec IS 2215
item Infotec IS 2216
item Infotec IS 2220
item Infotec IS 2220D
item Infotec IS 2225
item Infotec IS 2230
item Infotec IS 2235
item Infotec IS 2245
item Infotec IS 2255
item Infotec IS 2265
item Infotec IS 2275
item Infotec IS 2316
item Infotec IS 2320
item Infotec IS 2325
item Infotec IS 2416
item Infotec IS 2425
item Infotec IS 2430
item Infotec IS 2435
item Infotec IS 2445
item Infotec IS 3090
item Infotec IS 3110
item Infotec IS 3135
item Infotec ISC 1024c
item Infotec ISC 1032c
item Infotec ISC 2428
item Infotec ISC 2525
item Infotec ISC 2835
item Infotec ISC 3030
item Infotec ISC 3535
item Infotec ISC 3545
item Infotec ISC 4045
item Infotec ISC 4560
item Infotec ISC 5560
item Infotec ISC 615G
item Infotec MP 2550
item Infotec MP 2550B
item Infotec MP 3350
item Infotec MP 3350B
item Infotec MP 4000
item Infotec MP 4000B
item Infotec MP 5000
item Infotec MP 5000B
item Infotec MP C2003
item Infotec MP C2003Z
item Infotec MP C2004
item Infotec MP C2011
item Infotec MP C2050
item Infotec MP C2051
item Infotec MP C2503
item Infotec MP C2503Z
item Infotec MP C2504
item Infotec MP C2550
item Infotec MP C2551
item Infotec MP C2800
item Infotec MP C300
item Infotec MP C3001
item Infotec MP C3002
item Infotec MP C3003
item Infotec MP C3004
item Infotec MP C300SR
item Infotec MP C3300
item Infotec MP C3501
item Infotec MP C3502
item Infotec MP C3503
item Infotec MP C3504
item Infotec MP C400
item Infotec MP C4000
item Infotec MP C400SR
item Infotec MP C4501
item Infotec MP C4501A
item Infotec MP C4502
item Infotec MP C4502A
item Infotec MP C4503
item Infotec MP C4504
item Infotec MP C5000
item Infotec MP C5501
item Infotec MP C5501A
item Infotec MP C5502
item Infotec MP C5502A
item Infotec MP C5503
item Infotec MP C5504
item Infotec MP C6000
item Infotec MP C6003
item Infotec MP C6004
item Infotec MP C6501
item Infotec MP C6502
item Infotec MP C6503
item Infotec MP C7500
item Infotec MP C7501
item Infotec MP C8002
item Infotec MP C8003
item Infotec Pro C5100S
item Infotec Pro C5110S
item Infotec Pro C5200S
item Infotec Pro C5210S
item Infotec Pro C7100
item Infotec Pro C7100S
item Infotec Pro C7110
item Infotec Pro C7110S
item Kyocera CS-1815
item Kyocera CS-2525E
item Kyocera CS-3225E
item Kyocera CS-3232E
item Kyocera CS-4035E
item Kyocera CS-250ci
item Kyocera CS-300ci
item Kyocera CS-3050ci
item Kyocera CS-3550ci
item Kyocera CS-400ci
item Kyocera CS-500ci
item Kyocera Ci-1100
item Kyocera F-1010
item Kyocera FS-600 - KPDL-2
item Kyocera FS-600
item Kyocera FS-680
item Kyocera FS-800
item Kyocera FS-920
item Kyocera FS-1000
item Kyocera FS-1000+
item Kyocera FS-1010
item Kyocera FS-1018MFP
item Kyocera FS-1020D
item Kyocera FS-1030D
item Kyocera FS-1050
item Kyocera FS-1118MFP
item Kyocera FS-1135MFP
item Kyocera FS-1200
item Kyocera FS-1600
item Kyocera FS-1600+
item Kyocera FS-1700
item Kyocera FS-1700+
item Kyocera FS-1714M
item Kyocera FS-1750
item Kyocera FS-1800
item Kyocera FS-1800+
item Kyocera FS-1900
item Kyocera FS-1920
item Kyocera FS-2000D
item Kyocera FS-3500
item Kyocera FS-3600
item Kyocera FS-3600+
item Kyocera FS-3700
item Kyocera FS-3700+
item Kyocera FS-3718M
item Kyocera FS-3750
item Kyocera FS-3800
item Kyocera FS-3820N
item Kyocera FS-3830N
item Kyocera FS-3900DN
item Kyocera FS-4000DN
item Kyocera FS-5800C
item Kyocera FS-5900C
item Kyocera FS-6020
item Kyocera FS-6026
item Kyocera FS-6300
item Kyocera FS-6500
item Kyocera FS-6500+
item Kyocera FS-6700
item Kyocera FS-6750
item Kyocera FS-6900
item Kyocera FS-6950DN
item Kyocera FS-7000
item Kyocera FS-7000+
item Kyocera FS-7028M
item Kyocera FS-8000C
item Kyocera FS-9000
item Kyocera FS-9100DN
item Kyocera FS-9130DN
item Kyocera FS-9500DN
item Kyocera FS-9530DN
item Kyocera FS-C5015N
item Kyocera FS-C5016N
item Kyocera FS-C5020N
item Kyocera FS-C5025N
item Kyocera FS-C5030N
item Kyocera FS-C5100DN
item Kyocera FS-C5200DN
item Kyocera FS-C5300DN
item Kyocera FS-C5350DN
item Kyocera FS-C5400DN
item Kyocera FS-C8008N
item Kyocera FS-C8100DN
item Kyocera FS-C8100DN+
item Kyocera KM-1510
item Kyocera KM-1530
item Kyocera KM-1810
item Kyocera KM-1815
item Kyocera KM-1820
item Kyocera KM-2030
item Kyocera KM-2530
item Kyocera KM-3050
item Kyocera KM-3530
item Kyocera KM-4050
item Kyocera KM-4230
item Kyocera KM-4230/5230
item Kyocera KM-4530
item Kyocera KM-5050
item Kyocera KM-5230
item Kyocera KM-5530
item Kyocera KM-6030
item Kyocera KM-6230
item Kyocera KM-8030
item Kyocera KM-C830
item Kyocera KM-C850
item Kyocera KM-C2520
item Kyocera KM-C2525E
item Kyocera KM-C2630
item Kyocera KM-C3225
item Kyocera KM-C3225E
item Kyocera KM-C3232
item Kyocera KM-C3232E
item Kyocera KM-C4035E
item Kyocera TASKalfa 250ci
item Kyocera TASKalfa 300ci
item Kyocera TASKalfa 400ci
item Kyocera TASKalfa 500ci
item Lanier 5622
item Lanier 5627
item Lanier 5632
item Lanier 5635
item Lanier 5645
item Lanier LC155
item Lanier LD0105
item Lanier LD015
item Lanier LD035
item Lanier LD045
item Lanier LD060
item Lanier LD075
item Lanier LD090
item Lanier LD115
item Lanier LD116
item Lanier LD118
item Lanier LD118d
item Lanier LD120
item Lanier LD120d
item Lanier LD122
item Lanier LD124c
item Lanier LD127
item Lanier LD132
item Lanier LD132c
item Lanier LD135
item Lanier LD145
item Lanier LD151
item Lanier LD160
item Lanier LD160c
item Lanier LD175
item Lanier LD225
item Lanier LD230
item Lanier LD235
item Lanier LD245
item Lanier LD328c
item Lanier LD335c
item Lanier LD345c
item Lanier LD 130C
item Lanier LD 130CSR
item Lanier LD 140C
item Lanier LD 140CSR
item Lanier LD 620C
item Lanier LD 625C
item Lanier MP2500/LD125
item Lanier MP 1100/LD1100
item Lanier MP 1350/LD1135
item Lanier MP 1600/LD316
item Lanier MP 161/LD016
item Lanier MP 2000/LD320d
item Lanier MP 2510/LD325
item Lanier MP 2550B/LD425B
item Lanier MP 2550/LD425
item Lanier MP 3010/LD330
item Lanier MP 3350B/LD433B
item Lanier MP 3350/LD433
item Lanier MP 3500/LD335
item Lanier MP 4000B/LD040B
item Lanier MP 4000/LD040
item Lanier MP 4500/LD345
item Lanier MP 5000B/LD050B
item Lanier MP 5000/LD050
item Lanier MP 5500/LD255
item Lanier MP 6500/LD265
item Lanier MP 7500/LD275
item Lanier MP 9000/LD190
item Lanier MP C1500/LD215c
item Lanier MP C4501A/LD645CA
item Lanier MP C5501A/LD655CA
item Lanier MP C2003
item Lanier MP C2004
item Lanier MP C2050/LD520C
item Lanier MP C2500/LD425c
item Lanier MP C2503
item Lanier MP C2504
item Lanier MP C2550/LD525C
item Lanier MP C2800/LD528C
item Lanier MP C300
item Lanier MP C3000/LD430c
item Lanier MP C3001/LD630C
item Lanier MP C3002
item Lanier MP C3003
item Lanier MP C3004
item Lanier MP C300SR
item Lanier MP C3300/LD533C
item Lanier MP C3500/LD435c
item Lanier MP C3501/LD635C
item Lanier MP C3502
item Lanier MP C3503
item Lanier MP C3504
item Lanier MP C400
item Lanier MP C4000/LD540C
item Lanier MP C400SR
item Lanier MP C4500/LD445c
item Lanier MP C4501/LD645C
item Lanier MP C4502
item Lanier MP C4502A
item Lanier MP C4503
item Lanier MP C4504
item Lanier MP C5000/LD550C
item Lanier MP C5501/LD655C
item Lanier MP C5502
item Lanier MP C5502A
item Lanier MP C5503
item Lanier MP C6000/LD260c
item Lanier MP C6003
item Lanier MP C6004
item Lanier MP C6501/LD365C
item Lanier MP C6502
item Lanier MP C6503
item Lanier MP C7500/LD275c
item Lanier MP C7501/LD375C
item Lanier MP C8002
item Lanier MP C8003
item Lanier Pro C5100S
item Lanier Pro C5110S
item Lanier Pro C5200S
item Lanier Pro C5210S
item Lanier Pro C7100
item Lanier Pro C7100S
item Lanier Pro C7110
item Lanier Pro C7110S
item Lanier SG3110DN
item Lanier SG3110DNw
item Lanier SG3110SFNw
item Lexmark 4076
item Lexmark Optra E
item Lexmark Optra E+
item Lexmark Optra E220
item Lexmark Optra E321
item Lexmark Optra E323
item Lexmark Valuewriter 300
item Minolta PagePro 6
item Minolta PagePro 6e
item Minolta PagePro 6ex
item Minolta PagePro 8
item Minolta PagePro 8L
item Minolta PagePro 1100
item NEC SuperScript 660i
item NEC SuperScript 860
item NEC SuperScript 870
item NEC SuperScript 1260
item NEC SuperScript 1400
item NEC SuperScript 1800
item NRG 10515/10518/10512
item NRG 2205/2238/2212
item NRG 2705/2738/2712
item NRG 3205/3238/3212
item NRG 3525/3508/3502
item NRG 3545/3518/3532
item NRG 4525/4508/4502
item NRG 4545/4518/4532
item NRG 6002/6005/6008
item NRG 7502/7505/7508
item NRG 9005/9008/9002
item NRG CS555
item NRG DSc424
item NRG DSc428
item NRG DSc432
item NRG DSc435
item NRG DSc445
item NRG DSc460
item NRG DSm415
item NRG DSm615
item NRG DSm616
item NRG DSm618
item NRG DSm618d
item NRG DSm620
item NRG DSm620d
item NRG DSm622
item NRG DSm627
item NRG DSm632
item NRG DSm635
item NRG DSm645
item NRG DSm651
item NRG DSm660
item NRG DSm675
item NRG DSm725
item NRG DSm730
item NRG DSm735
item NRG DSm745
item NRG MP 1100
item NRG MP 1350
item NRG MP 1600
item NRG MP 161
item NRG MP 2000
item NRG MP 2500
item NRG MP 2510
item NRG MP 2550
item NRG MP 2550B
item NRG MP 3010
item NRG MP 3350
item NRG MP 3350B
item NRG MP 3500
item NRG MP 4000
item NRG MP 4000B
item NRG MP 4500
item NRG MP 5000
item NRG MP 5000B
item NRG MP 5500
item NRG MP 6500
item NRG MP 7500
item NRG MP 9000
item NRG MP C1500sp
item NRG MP C2003
item NRG MP C2003Z
item NRG MP C2004
item NRG MP C2011
item NRG MP C2050
item NRG MP C2051
item NRG MP C2500
item NRG MP C2503
item NRG MP C2503Z
item NRG MP C2504
item NRG MP C2550
item NRG MP C2551
item NRG MP C2800
item NRG MP C300
item NRG MP C3000
item NRG MP C3001
item NRG MP C3002
item NRG MP C3003
item NRG MP C3004
item NRG MP C300SR
item NRG MP C3300
item NRG MP C3500
item NRG MP C3501
item NRG MP C3502
item NRG MP C3503
item NRG MP C3504
item NRG MP C400
item NRG MP C4000
item NRG MP C400SR
item NRG MP C4500
item NRG MP C4501
item NRG MP C4501A
item NRG MP C4502
item NRG MP C4502A
item NRG MP C4503
item NRG MP C4504
item NRG MP C5000
item NRG MP C5501
item NRG MP C5501A
item NRG MP C5502
item NRG MP C5502A
item NRG MP C5503
item NRG MP C5504
item NRG MP C6000
item NRG MP C6003
item NRG MP C6004
item NRG MP C6501
item NRG MP C6502
item NRG MP C6503
item NRG MP C7500
item NRG MP C7501
item NRG MP C8002
item NRG MP C8003
item NRG Pro C5100S
item NRG Pro C5110S
item NRG Pro C5200S
item NRG Pro C5210S
item NRG Pro C7100
item NRG Pro C7100S
item NRG Pro C7110
item NRG Pro C7110S
item NRG SG3110DN
item NRG SG3110DNw
item NRG SG3110SFNw
item Oki B401d
item Oki B430
item Oki B4350
item Oki C5300
item Oki C5400
item Oki C7300
item Oki C8800
item Oki C9200
item Oki C9400
item Oki OL400
item Oki OL400e
item Oki OL400ex
item Oki OL410e
item Oki OL600e
item Oki OL610e/S
item Oki OL800
item Oki OL810ex
item Oki Okipage 6e
item Oki Okipage 6ex
item Oki Okipage 8p
item Oki Okipage 10e
item Oki Okipage 10ex
item Oki Okipage 14ex
item Oki Super 6e
item Olivetti JP350S
item Olivetti PG 306
item PCPI 1030
item Panasonic DP-180
item Panasonic DP-C265
item Panasonic DP-C305
item Panasonic DP-C322
item Panasonic DP-C405
item Panasonic KX-P4410
item Panasonic KX-P4450
item Panasonic KX-P6150
item Panasonic KX-P6500
item Raven LP-410
item Ricoh Aficio 401
item Ricoh Aficio 700
item Ricoh Aficio 1022
item Ricoh Aficio 1027
item Ricoh Aficio 1032
item Ricoh Aficio 1035
item Ricoh Aficio 1045
item Ricoh Aficio 1060
item Ricoh Aficio 1075
item Ricoh Aficio 1515
item Ricoh Aficio 2015
item Ricoh Aficio 2016
item Ricoh Aficio 2018
item Ricoh Aficio 2018D
item Ricoh Aficio 2020
item Ricoh Aficio 2020D
item Ricoh Aficio 2022
item Ricoh Aficio 2027
item Ricoh Aficio 2032
item Ricoh Aficio 2035
item Ricoh Aficio 2035e
item Ricoh Aficio 2045
item Ricoh Aficio 2045e
item Ricoh Aficio 2051
item Ricoh Aficio 2060
item Ricoh Aficio 2075
item Ricoh Aficio 2090
item Ricoh Aficio 2105
item Ricoh Aficio 220
item Ricoh Aficio 3025
item Ricoh Aficio 3030
item Ricoh Aficio 3035
item Ricoh Aficio 3045
item Ricoh Aficio 3224C
item Ricoh Aficio 3228C
item Ricoh Aficio 3232C
item Ricoh Aficio 3235C
item Ricoh Aficio 3245C
item Ricoh Aficio 3260C
item Ricoh Aficio Color 5560
item Ricoh Aficio MP 1100
item Ricoh Aficio MP 1350
item Ricoh Aficio MP 1600
item Ricoh Aficio MP 161
item Ricoh Aficio MP 2000
item Ricoh Aficio MP 2500
item Ricoh Aficio MP 2510
item Ricoh Aficio MP 2550
item Ricoh Aficio MP 2550B
item Ricoh Aficio MP 3010
item Ricoh Aficio MP 3350
item Ricoh Aficio MP 3350B
item Ricoh Aficio MP 3500
item Ricoh Aficio MP 4000
item Ricoh Aficio MP 4000B
item Ricoh Aficio MP 4500
item Ricoh Aficio MP 5000
item Ricoh Aficio MP 5000B
item Ricoh Aficio MP 5500
item Ricoh Aficio MP 6500
item Ricoh Aficio MP 7500
item Ricoh Aficio MP 9000
item Ricoh Aficio MP C2050
item Ricoh Aficio MP C2051
item Ricoh Aficio MP C2500
item Ricoh Aficio MP C2550
item Ricoh Aficio MP C2551
item Ricoh Aficio MP C2800
item Ricoh Aficio MP C300
item Ricoh Aficio MP C3000
item Ricoh Aficio MP C3001
item Ricoh Aficio MP C3002
item Ricoh Aficio MP C300SR
item Ricoh Aficio MP C3300
item Ricoh Aficio MP C3500
item Ricoh Aficio MP C3501
item Ricoh Aficio MP C3502
item Ricoh Aficio MP C400
item Ricoh Aficio MP C4000
item Ricoh Aficio MP C400SR
item Ricoh Aficio MP C4500
item Ricoh Aficio MP C4501
item Ricoh Aficio MP C4501A
item Ricoh Aficio MP C4502
item Ricoh Aficio MP C4502A
item Ricoh Aficio MP C5000
item Ricoh Aficio MP C5501
item Ricoh Aficio MP C5501A
item Ricoh Aficio MP C5502
item Ricoh Aficio MP C5502A
item Ricoh Aficio MP C6000
item Ricoh Aficio MP C6501
item Ricoh Aficio MP C7500
item Ricoh Aficio MP C7501
item Ricoh Aficio SG 3110DN
item Ricoh GX 3050N
item Ricoh GX 3050SFN
item Ricoh GX 5050N
item Ricoh GX E3350N
item Ricoh GX E5550N
item Ricoh MP C1500/615C
item Ricoh MP C2003
item Ricoh MP C2003Z
item Ricoh MP C2004
item Ricoh MP C2011
item Ricoh MP C2094J
item Ricoh MP C2503
item Ricoh MP C2503Z
item Ricoh MP C2504
item Ricoh MP C2594J
item Ricoh MP C3003
item Ricoh MP C3004
item Ricoh MP C3503
item Ricoh MP C3504
item Ricoh MP C4503
item Ricoh MP C4504
item Ricoh MP C5503
item Ricoh MP C5504
item Ricoh MP C6003
item Ricoh MP C6004
item Ricoh MP C6502
item Ricoh MP C6503
item Ricoh MP C8002
item Ricoh MP C8003
item Ricoh Pro C5100S
item Ricoh Pro C5110S
item Ricoh Pro C5200S
item Ricoh Pro C5210S
item Ricoh Pro C7100
item Ricoh Pro C7100S
item Ricoh Pro C7110
item Ricoh Pro C7110S
item Ricoh SG3120BSFNw
item Samsung CLP-620
item Samsung CLP-660N
item Samsung CLP-660ND
item Samsung ML-85
item Samsung ML-1250
item Samsung ML-1450
item Samsung ML-1450PS
item Samsung ML-1650
item Samsung ML-1651N
item Samsung ML-1750
item Samsung ML-2150
item Samsung ML-2150PS
item Samsung ML-2151N
item Samsung ML-2151NPS
item Samsung ML-2152W
item Samsung ML-2152WPS
item Samsung ML-2250
item Samsung ML-2550
item Samsung ML-2551N
item Samsung ML-2552W
item Samsung ML-4600
item Samsung ML-5000a
item Samsung ML-6000
item Samsung ML-6100
item Samsung ML-7000
item Samsung ML-7000N
item Samsung ML-7000P
item Samsung ML-7050
item Samsung ML-7300
item Samsung ML-7300N
item Samsung QL-5100A
item Samsung QL-6050
item Samsung ProXpress SL-M3820ND
item Savin 2522
item Savin 2527
item Savin 2532
item Savin 2535/2235
item Savin 2545/2245
item Savin 2560
item Savin 2575
item Savin 3515
item Savin 40105
item Savin 4015
item Savin 4018
item Savin 4018d
item Savin 4022
item Savin 4027
item Savin 4035/4135g
item Savin 4035e/4135eG
item Savin 4045/4145g
item Savin 4045e/4145eG
item Savin 4051
item Savin 4060
item Savin 4075
item Savin 4090
item Savin 7025
item Savin 8016
item Savin 8020
item Savin 8020d
item Savin 8025
item Savin 8025e
item Savin 8030
item Savin 8030e
item Savin 8035/8035g
item Savin 8035e
item Savin 8045/8045g
item Savin 8045e
item Savin 8055
item Savin 8065
item Savin 8075
item Savin 8090
item Savin 8110
item Savin 8135
item Savin 816
item Savin 9016
item Savin 9021d
item Savin 9025
item Savin 9025b
item Savin 9033
item Savin 9033b
item Savin 9040
item Savin 9040b
item Savin 9050
item Savin 9050b
item Savin C2410
item Savin C2525
item Savin C2824
item Savin C2828
item Savin C3030
item Savin C3210e
item Savin C3333
item Savin C3528
item Savin C3535
item Savin C4040
item Savin C4535
item Savin C4540
item Savin C5050
item Savin C6045
item Savin C6055
item Savin C7570
item Savin C9020
item Savin C9025
item Savin C9065
item Savin C9075
item Savin C9120
item Savin C9125
item Savin C9130
item Savin C9135
item Savin C9145
item Savin C9145A
item Savin C9155
item Savin C9155A
item Savin C 230
item Savin C 230SR
item Savin C 240
item Savin C 240SR
item Savin MP C2003
item Savin MP C2004
item Savin MP C2503
item Savin MP C2504
item Savin MP C3002
item Savin MP C3003
item Savin MP C3004
item Savin MP C3502
item Savin MP C3503
item Savin MP C3504
item Savin MP C4502
item Savin MP C4502A
item Savin MP C4503
item Savin MP C4504
item Savin MP C5502
item Savin MP C5502A
item Savin MP C5503
item Savin MP C6003
item Savin MP C6004
item Savin MP C6502
item Savin MP C6503
item Savin MP C8002
item Savin MP C8003
item Savin Pro C5100S
item Savin Pro C5110S
item Savin Pro C5200S
item Savin Pro C5210S
item Savin Pro C7100
item Savin Pro C7100S
item Savin Pro C7110
item Savin Pro C7110S
item Savin SDC555
item Savin SG3110DN
item Savin SGC 1506
item Seiko SpeedJET 200
item Sharp AR-161
item Sharp AR-BC260
item Sharp AR-BC320
item Sharp AR-C170FP
item Sharp AR-C170M
item Sharp AR-C172FP
item Sharp AR-C172M
item Sharp AR-C260
item Sharp AR-C260F
item Sharp AR-C260FP
item Sharp AR-C260M
item Sharp AR-C260P
item Sharp AR-C260S
item Sharp AR-C261F
item Sharp AR-C261FP
item Sharp AR-C261M
item Sharp AR-C261S
item Sharp AR-C262FP
item Sharp AR-C262M
item Sharp AR-C262S
item Sharp AR-M257
item Sharp MX-2300FG
item Sharp MX-2300G
item Sharp MX-2300N
item Sharp MX-2700FG
item Sharp MX-2700G
item Sharp MX-2700N
item Sharp MX-3500FN
item Sharp MX-3500N
item Sharp MX-3501FN
item Sharp MX-3501N
item Sharp MX-4500FN
item Sharp MX-4500N
item Sharp MX-4501FN
item Sharp MX-4501N
item Sony IJP-V100
item Star LS-04
item Star LaserPrinter 8
item Tally MT908
item Tektronix Phaser 750DP
item Tektronix Phaser 750DX
item Tektronix Phaser 750N
item Tektronix Phaser 750P
item Toshiba e-Studio 220cp
item Toshiba e-Studio 2830c
item Toshiba e-Studio 3530c
item Toshiba e-Studio 4500c
item Toshiba e-Studio 4520c
item Toshiba e-Studio 5500c
item Xerox Able 1406
item Xerox DocuPrint 4508
item Xerox DocuPrint C20
item Xerox DocuPrint N4512
item Xerox DocuPrint N4512PS
item Xerox DocuPrint P12
item Xerox DocuPrint P1202
item Xerox DocuPrint P8e
item Xerox Document Centre 400
item Xerox Phaser 2135
item Xerox Phaser 3160N
item Xerox Phaser 4400B
item Xerox Phaser 4400DT
item Xerox Phaser 4400DX
item Xerox Phaser 4400N
item Xerox Phaser 4500B
item Xerox Phaser 4500DT
item Xerox Phaser 4500DX
item Xerox Phaser 4500N
item Xerox Phaser 4510B
item Xerox Phaser 4510DT
item Xerox Phaser 4510DX
item Xerox Phaser 4510N
item Xerox Phaser 5500B
item Xerox Phaser 5500DN
item Xerox Phaser 5500DT
item Xerox Phaser 5500DX
item Xerox Phaser 5500N
item Xerox Phaser 6130N
item Xerox Phaser 6180DN
item Xerox Phaser 6180MFP-D
item Xerox Phaser 6200B
item Xerox Phaser 6200DP
item Xerox Phaser 6200DX
item Xerox Phaser 6200N
item Xerox Phaser 6250B
item Xerox Phaser 6250DP
item Xerox Phaser 6250DT
item Xerox Phaser 6250DX
item Xerox Phaser 6250N
item Xerox Phaser 6300DN
item Xerox Phaser 6300N
item Xerox Phaser 6350DP
item Xerox Phaser 6350DT
item Xerox Phaser 6350DX
item Xerox Phaser 6360DN
item Xerox Phaser 6360DX
item Xerox Phaser 7300B
item Xerox Phaser 7300DN
item Xerox Phaser 7300DT
item Xerox Phaser 7300DX
item Xerox Phaser 7300N
item Xerox Phaser 7400DN
item Xerox Phaser 7400DT
item Xerox Phaser 7400DX
item Xerox Phaser 7400DXF
item Xerox Phaser 7400N
item Xerox Phaser 7700DN
item Xerox Phaser 7700DX
item Xerox Phaser 7700GX
item Xerox Phaser 7750B
item Xerox Phaser 7750DN
item Xerox Phaser 7750DXF
item Xerox Phaser 7750GX
item Xerox Phaser 7760DN
item Xerox Phaser 7760DX
item Xerox Phaser 7760GX
item Xerox Phaser 8400B
item Xerox Phaser 8400BD
item Xerox Phaser 8400DP
item Xerox Phaser 8400DX
item Xerox Phaser 8400N
item Xerox Phaser 8500DN
item Xerox Phaser 8500N
item Xerox Phaser 8550DP
item Xerox Phaser 8550DT
item Xerox Phaser 8550DX
item Xerox Phaser 8560DN
item Xerox Phaser 8860
item Xerox WorkCentre 7345
item Xerox WorkCentre C2424
item Xerox WorkCentre M118
item Datamax-ONeil I4212e Mark II
item Datamax-ONeil I4310e Mark II
item Datamax-ONeil I4606e Mark II
item Datamax-ONeil E4204B Mark III
item Datamax-ONeil E4304B Mark III
item Datamax-ONeil E4205A Mark III
item Datamax-ONeil E4305A Mark III
item Datamax-ONeil E4206P Mark III
item Datamax-ONeil E4305P Mark III
item Datamax-ONeil E4206L Mark III
item Datamax-ONeil E4305L Mark III
item Datamax-ONeil RL3e
item Datamax-ONeil RL4e
item Datamax-ONeil H4212
item Datamax-ONeil H4212X
item Datamax-ONeil H4310
item Datamax-ONeil H4310X
item Datamax-ONeil H4408
item Datamax-ONeil H4606
item Datamax-ONeil H4606X
item Datamax-ONeil H6210
item Datamax-ONeil H6210X
item Datamax-ONeil H6212
item Datamax-ONeil H6212X
item Datamax-ONeil H6308
item Datamax-ONeil H6310X
item Datamax-ONeil H8308
item Datamax-ONeil H8308X
item Honeywell RP2
item Honeywell RP4
item Compaq IJ1200
item Lexmark X73
item Lexmark Z42
item Lexmark Z43
item Lexmark Z52
item Lexmark Z53
item Olympus P-10
item Olympus P-11
item Olympus P-200
item Olympus P-300
item Olympus P-300E
item Olympus P-300U
item Olympus P-330E
item Olympus P-330NE
item Olympus P-400
item Olympus P-440
item Olympus P-S100
item Canon CP-10
item Canon CP-100
item Canon CP-200
item Canon CP-220
item Canon CP-300
item Canon CP-330
item Canon SELPHY CP400
item Canon SELPHY CP500
item Canon SELPHY CP510
item Canon SELPHY CP520
item Canon SELPHY CP530
item Canon SELPHY CP600
item Canon SELPHY CP710
item Canon SELPHY CP720
item Canon SELPHY CP730
item Canon SELPHY CP740
item Canon SELPHY CP750
item Canon SELPHY CP760
item Canon SELPHY CP770
item Canon SELPHY CP780
item Canon SELPHY CP790
item Canon SELPHY CP800
item Canon SELPHY CP810
item Canon SELPHY CP820
item Canon SELPHY CP900
item Canon SELPHY CP910
item Canon SELPHY CP1000
item Canon SELPHY CP1200
item Canon SELPHY CP1300
item Canon SELPHY ES1
item Canon SELPHY ES2
item Canon SELPHY ES3
item Canon SELPHY ES20
item Canon SELPHY ES30
item Canon SELPHY ES40
item CIAAT Brava 21
item Citizen CW-01
item Citizen CW-02
item Citizen CX
item Citizen CX-02
item Citizen CX-W
item Citizen CY
item Citizen CY-02
item Citizen OP900
item Citizen OP900II
item Dai Nippon Printing DS40
item Dai Nippon Printing DS80
item Dai Nippon Printing DS80DX
item Dai Nippon Printing DS620
item Dai Nippon Printing DS820
item Dai Nippon Printing DSRX1
item Dai Nippon Printing SL10
item Dai Nippon Printing SL20
item Fujifilm ASK-300
item Fujifilm ASK-2000
item Fujifilm ASK-2500
item Fujifilm ASK-4000
item Fujifilm FinePix-NX-500
item Fujifilm Printpix-CX-400
item Fujifilm Printpix-CX-550
item Kodak 305
item Kodak 605
item Kodak 1400
item Kodak 6800
item Kodak 6850
item Kodak 7000
item Kodak 7010
item Kodak 7015
item Kodak 805
item Kodak 8500
item Kodak 8800
item Kodak 8810
item Kodak 9810
item Kodak EasyShare-G600-Printer-Dock
item Kodak Easyshare-Printer-Dock
item Kodak PD-4000
item Kodak PD-6000
item Kodak Photo-Printer
item Kodak Photo-Printer-500
item Kodak Printer-Dock-Plus
item Kodak Printer-Dock-Plus-S3
item Magicard Tango 2E
item Magicard Rio 2E
item Mitsubishi CP-3020D
item Mitsubishi CP-3020DA
item Mitsubishi CP-3020DAE
item Mitsubishi CP-3020DE
item Mitsubishi CP-3020DU
item Mitsubishi CP-3800DW
item Mitsubishi CP-9500DW
item Mitsubishi CP-9550D
item Mitsubishi CP-9550DW
item Mitsubishi CP-9550DW-S
item Mitsubishi CP-9550DZ
item Mitsubishi CP-9600DW
item Mitsubishi CP-9800D
item Mitsubishi CP-9800DW
item Mitsubishi CP-9800DW-S
item Mitsubishi CP-9800DZ
item Mitsubishi CP-9810D
item Mitsubishi CP-9810DW
item Mitsubishi CP-D80DW
item Mitsubishi CP-D90DW
item Mitsubishi CP-D70DW
item Mitsubishi CP-D707DW
item Mitsubishi CP-K60DW-S
item Mitsubishi P93D
item Mitsubishi P95D
item Nidac Copal DPB-4000
item Nidac Copal DPB-6000
item Nidac Copal DPB-7000
item Shinko CHC-S1245
item Shinko CHC-S2145
item Shinko CHC-S6145
item Shinko CHC-S6245
item Shinko CHC-S9045
item Sinfonia CHC-S1245/E1
item Sinfonia CHC-S2145/S2
item Sinfonia CHC-S2245/S2
item Sinfonia CHC-S6145/CS2
item Sinfonia CHC-S6245/CE1
item Sony UP-DP10
item Sony UP-DR150
item Sony DPP-EX5
item Sony DPP-EX7
item Sony UP-DR100
item Sony UP-DR200
item Sony UP-CR10L
item Sony UP-D895
item Sony UP-D897
item Sony UP-D898
item Sony UP-CR20L
item Sony UP-DR80MD

end enumerate")
   (home-page "http://gimp-print.sourceforge.net/")
   (license license:gpl2+)))
